#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RetailItemDescription import RetailItemDescription


class KoubeiRetailItemQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiRetailItemQueryResponse, self).__init__()
        self._cover = None
        self._descriptions = None
        self._discount_rate = None
        self._gmt_end = None
        self._gmt_start = None
        self._item_id = None
        self._item_status = None
        self._original_amount = None
        self._picture_list = None
        self._reduce_to_amount = None
        self._shop_list = None
        self._sku_list = None
        self._title = None
        self._type = None
        self._value_amount = None

    @property
    def cover(self):
        return self._cover

    @cover.setter
    def cover(self, value):
        self._cover = value
    @property
    def descriptions(self):
        return self._descriptions

    @descriptions.setter
    def descriptions(self, value):
        if isinstance(value, list):
            self._descriptions = list()
            for i in value:
                if isinstance(i, RetailItemDescription):
                    self._descriptions.append(i)
                else:
                    self._descriptions.append(RetailItemDescription.from_alipay_dict(i))
    @property
    def discount_rate(self):
        return self._discount_rate

    @discount_rate.setter
    def discount_rate(self, value):
        self._discount_rate = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_start(self):
        return self._gmt_start

    @gmt_start.setter
    def gmt_start(self, value):
        self._gmt_start = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_status(self):
        return self._item_status

    @item_status.setter
    def item_status(self, value):
        self._item_status = value
    @property
    def original_amount(self):
        return self._original_amount

    @original_amount.setter
    def original_amount(self, value):
        self._original_amount = value
    @property
    def picture_list(self):
        return self._picture_list

    @picture_list.setter
    def picture_list(self, value):
        if isinstance(value, list):
            self._picture_list = list()
            for i in value:
                self._picture_list.append(i)
    @property
    def reduce_to_amount(self):
        return self._reduce_to_amount

    @reduce_to_amount.setter
    def reduce_to_amount(self, value):
        self._reduce_to_amount = value
    @property
    def shop_list(self):
        return self._shop_list

    @shop_list.setter
    def shop_list(self, value):
        if isinstance(value, list):
            self._shop_list = list()
            for i in value:
                self._shop_list.append(i)
    @property
    def sku_list(self):
        return self._sku_list

    @sku_list.setter
    def sku_list(self, value):
        if isinstance(value, list):
            self._sku_list = list()
            for i in value:
                self._sku_list.append(i)
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def value_amount(self):
        return self._value_amount

    @value_amount.setter
    def value_amount(self, value):
        self._value_amount = value

    def parse_response_content(self, response_content):
        response = super(KoubeiRetailItemQueryResponse, self).parse_response_content(response_content)
        if 'cover' in response:
            self.cover = response['cover']
        if 'descriptions' in response:
            self.descriptions = response['descriptions']
        if 'discount_rate' in response:
            self.discount_rate = response['discount_rate']
        if 'gmt_end' in response:
            self.gmt_end = response['gmt_end']
        if 'gmt_start' in response:
            self.gmt_start = response['gmt_start']
        if 'item_id' in response:
            self.item_id = response['item_id']
        if 'item_status' in response:
            self.item_status = response['item_status']
        if 'original_amount' in response:
            self.original_amount = response['original_amount']
        if 'picture_list' in response:
            self.picture_list = response['picture_list']
        if 'reduce_to_amount' in response:
            self.reduce_to_amount = response['reduce_to_amount']
        if 'shop_list' in response:
            self.shop_list = response['shop_list']
        if 'sku_list' in response:
            self.sku_list = response['sku_list']
        if 'title' in response:
            self.title = response['title']
        if 'type' in response:
            self.type = response['type']
        if 'value_amount' in response:
            self.value_amount = response['value_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenPublicFollowBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicFollowBatchqueryResponse, self).__init__()
        self._count = None
        self._next_user_id = None
        self._open_id = None
        self._open_id_list = None
        self._user_id_list = None

    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def next_user_id(self):
        return self._next_user_id

    @next_user_id.setter
    def next_user_id(self, value):
        self._next_user_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def open_id_list(self):
        return self._open_id_list

    @open_id_list.setter
    def open_id_list(self, value):
        if isinstance(value, list):
            self._open_id_list = list()
            for i in value:
                self._open_id_list.append(i)
    @property
    def user_id_list(self):
        return self._user_id_list

    @user_id_list.setter
    def user_id_list(self, value):
        if isinstance(value, list):
            self._user_id_list = list()
            for i in value:
                self._user_id_list.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicFollowBatchqueryResponse, self).parse_response_content(response_content)
        if 'count' in response:
            self.count = response['count']
        if 'next_user_id' in response:
            self.next_user_id = response['next_user_id']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'open_id_list' in response:
            self.open_id_list = response['open_id_list']
        if 'user_id_list' in response:
            self.user_id_list = response['user_id_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.KbdishAreaInfo import KbdishAreaInfo


class KoubeiCateringDishAreaQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringDishAreaQueryResponse, self).__init__()
        self._kb_dish_area_list = None

    @property
    def kb_dish_area_list(self):
        return self._kb_dish_area_list

    @kb_dish_area_list.setter
    def kb_dish_area_list(self, value):
        if isinstance(value, list):
            self._kb_dish_area_list = list()
            for i in value:
                if isinstance(i, KbdishAreaInfo):
                    self._kb_dish_area_list.append(i)
                else:
                    self._kb_dish_area_list.append(KbdishAreaInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringDishAreaQueryResponse, self).parse_response_content(response_content)
        if 'kb_dish_area_list' in response:
            self.kb_dish_area_list = response['kb_dish_area_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniTipsStatisticQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniTipsStatisticQueryResponse, self).__init__()
        self._app_collect_cnt = None
        self._app_uv = None
        self._delivery_content = None
        self._delivery_id = None
        self._tips_collect_rate = None
        self._tips_collect_uv = None
        self._tips_expo_uv = None
        self._total_app_collect_cnt = None
        self._total_app_uv = None
        self._total_tips_collect_rate = None
        self._total_tips_collect_uv = None
        self._total_tips_expo_uv = None

    @property
    def app_collect_cnt(self):
        return self._app_collect_cnt

    @app_collect_cnt.setter
    def app_collect_cnt(self, value):
        self._app_collect_cnt = value
    @property
    def app_uv(self):
        return self._app_uv

    @app_uv.setter
    def app_uv(self, value):
        self._app_uv = value
    @property
    def delivery_content(self):
        return self._delivery_content

    @delivery_content.setter
    def delivery_content(self, value):
        self._delivery_content = value
    @property
    def delivery_id(self):
        return self._delivery_id

    @delivery_id.setter
    def delivery_id(self, value):
        self._delivery_id = value
    @property
    def tips_collect_rate(self):
        return self._tips_collect_rate

    @tips_collect_rate.setter
    def tips_collect_rate(self, value):
        self._tips_collect_rate = value
    @property
    def tips_collect_uv(self):
        return self._tips_collect_uv

    @tips_collect_uv.setter
    def tips_collect_uv(self, value):
        self._tips_collect_uv = value
    @property
    def tips_expo_uv(self):
        return self._tips_expo_uv

    @tips_expo_uv.setter
    def tips_expo_uv(self, value):
        self._tips_expo_uv = value
    @property
    def total_app_collect_cnt(self):
        return self._total_app_collect_cnt

    @total_app_collect_cnt.setter
    def total_app_collect_cnt(self, value):
        self._total_app_collect_cnt = value
    @property
    def total_app_uv(self):
        return self._total_app_uv

    @total_app_uv.setter
    def total_app_uv(self, value):
        self._total_app_uv = value
    @property
    def total_tips_collect_rate(self):
        return self._total_tips_collect_rate

    @total_tips_collect_rate.setter
    def total_tips_collect_rate(self, value):
        self._total_tips_collect_rate = value
    @property
    def total_tips_collect_uv(self):
        return self._total_tips_collect_uv

    @total_tips_collect_uv.setter
    def total_tips_collect_uv(self, value):
        self._total_tips_collect_uv = value
    @property
    def total_tips_expo_uv(self):
        return self._total_tips_expo_uv

    @total_tips_expo_uv.setter
    def total_tips_expo_uv(self, value):
        self._total_tips_expo_uv = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniTipsStatisticQueryResponse, self).parse_response_content(response_content)
        if 'app_collect_cnt' in response:
            self.app_collect_cnt = response['app_collect_cnt']
        if 'app_uv' in response:
            self.app_uv = response['app_uv']
        if 'delivery_content' in response:
            self.delivery_content = response['delivery_content']
        if 'delivery_id' in response:
            self.delivery_id = response['delivery_id']
        if 'tips_collect_rate' in response:
            self.tips_collect_rate = response['tips_collect_rate']
        if 'tips_collect_uv' in response:
            self.tips_collect_uv = response['tips_collect_uv']
        if 'tips_expo_uv' in response:
            self.tips_expo_uv = response['tips_expo_uv']
        if 'total_app_collect_cnt' in response:
            self.total_app_collect_cnt = response['total_app_collect_cnt']
        if 'total_app_uv' in response:
            self.total_app_uv = response['total_app_uv']
        if 'total_tips_collect_rate' in response:
            self.total_tips_collect_rate = response['total_tips_collect_rate']
        if 'total_tips_collect_uv' in response:
            self.total_tips_collect_uv = response['total_tips_collect_uv']
        if 'total_tips_expo_uv' in response:
            self.total_tips_expo_uv = response['total_tips_expo_uv']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialQuestionnareTaskVerifyModel(object):

    def __init__(self):
        self._buyer_user_ids = None
        self._ext_info = None
        self._qstn_id = None
        self._rmt_qstn_id = None

    @property
    def buyer_user_ids(self):
        return self._buyer_user_ids

    @buyer_user_ids.setter
    def buyer_user_ids(self, value):
        self._buyer_user_ids = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def qstn_id(self):
        return self._qstn_id

    @qstn_id.setter
    def qstn_id(self, value):
        self._qstn_id = value
    @property
    def rmt_qstn_id(self):
        return self._rmt_qstn_id

    @rmt_qstn_id.setter
    def rmt_qstn_id(self, value):
        self._rmt_qstn_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer_user_ids:
            if hasattr(self.buyer_user_ids, 'to_alipay_dict'):
                params['buyer_user_ids'] = self.buyer_user_ids.to_alipay_dict()
            else:
                params['buyer_user_ids'] = self.buyer_user_ids
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.qstn_id:
            if hasattr(self.qstn_id, 'to_alipay_dict'):
                params['qstn_id'] = self.qstn_id.to_alipay_dict()
            else:
                params['qstn_id'] = self.qstn_id
        if self.rmt_qstn_id:
            if hasattr(self.rmt_qstn_id, 'to_alipay_dict'):
                params['rmt_qstn_id'] = self.rmt_qstn_id.to_alipay_dict()
            else:
                params['rmt_qstn_id'] = self.rmt_qstn_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialQuestionnareTaskVerifyModel()
        if 'buyer_user_ids' in d:
            o.buyer_user_ids = d['buyer_user_ids']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'qstn_id' in d:
            o.qstn_id = d['qstn_id']
        if 'rmt_qstn_id' in d:
            o.rmt_qstn_id = d['rmt_qstn_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ExerciseCourseOpenModel import ExerciseCourseOpenModel
from alipay.aop.api.domain.ExerciseItemOpenModel import ExerciseItemOpenModel


class ExercisePlanOpenModel(object):

    def __init__(self):
        self._biz_type = None
        self._course_list = None
        self._item_list = None
        self._time_dimension_type = None
        self._values = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def course_list(self):
        return self._course_list

    @course_list.setter
    def course_list(self, value):
        if isinstance(value, list):
            self._course_list = list()
            for i in value:
                if isinstance(i, ExerciseCourseOpenModel):
                    self._course_list.append(i)
                else:
                    self._course_list.append(ExerciseCourseOpenModel.from_alipay_dict(i))
    @property
    def item_list(self):
        return self._item_list

    @item_list.setter
    def item_list(self, value):
        if isinstance(value, list):
            self._item_list = list()
            for i in value:
                if isinstance(i, ExerciseItemOpenModel):
                    self._item_list.append(i)
                else:
                    self._item_list.append(ExerciseItemOpenModel.from_alipay_dict(i))
    @property
    def time_dimension_type(self):
        return self._time_dimension_type

    @time_dimension_type.setter
    def time_dimension_type(self, value):
        self._time_dimension_type = value
    @property
    def values(self):
        return self._values

    @values.setter
    def values(self, value):
        self._values = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.course_list:
            if isinstance(self.course_list, list):
                for i in range(0, len(self.course_list)):
                    element = self.course_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.course_list[i] = element.to_alipay_dict()
            if hasattr(self.course_list, 'to_alipay_dict'):
                params['course_list'] = self.course_list.to_alipay_dict()
            else:
                params['course_list'] = self.course_list
        if self.item_list:
            if isinstance(self.item_list, list):
                for i in range(0, len(self.item_list)):
                    element = self.item_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_list[i] = element.to_alipay_dict()
            if hasattr(self.item_list, 'to_alipay_dict'):
                params['item_list'] = self.item_list.to_alipay_dict()
            else:
                params['item_list'] = self.item_list
        if self.time_dimension_type:
            if hasattr(self.time_dimension_type, 'to_alipay_dict'):
                params['time_dimension_type'] = self.time_dimension_type.to_alipay_dict()
            else:
                params['time_dimension_type'] = self.time_dimension_type
        if self.values:
            if hasattr(self.values, 'to_alipay_dict'):
                params['values'] = self.values.to_alipay_dict()
            else:
                params['values'] = self.values
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExercisePlanOpenModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'course_list' in d:
            o.course_list = d['course_list']
        if 'item_list' in d:
            o.item_list = d['item_list']
        if 'time_dimension_type' in d:
            o.time_dimension_type = d['time_dimension_type']
        if 'values' in d:
            o.values = d['values']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpCreditlinkloanAuthorderSubmitModel(object):

    def __init__(self):
        self._loan_type = None
        self._merchant_biz_no = None

    @property
    def loan_type(self):
        return self._loan_type

    @loan_type.setter
    def loan_type(self, value):
        self._loan_type = value
    @property
    def merchant_biz_no(self):
        return self._merchant_biz_no

    @merchant_biz_no.setter
    def merchant_biz_no(self, value):
        self._merchant_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.loan_type:
            if hasattr(self.loan_type, 'to_alipay_dict'):
                params['loan_type'] = self.loan_type.to_alipay_dict()
            else:
                params['loan_type'] = self.loan_type
        if self.merchant_biz_no:
            if hasattr(self.merchant_biz_no, 'to_alipay_dict'):
                params['merchant_biz_no'] = self.merchant_biz_no.to_alipay_dict()
            else:
                params['merchant_biz_no'] = self.merchant_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpCreditlinkloanAuthorderSubmitModel()
        if 'loan_type' in d:
            o.loan_type = d['loan_type']
        if 'merchant_biz_no' in d:
            o.merchant_biz_no = d['merchant_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TemplateActionInfoDTO import TemplateActionInfoDTO
from alipay.aop.api.domain.TemplateCardLevelConfDTO import TemplateCardLevelConfDTO
from alipay.aop.api.domain.TemplateColumnInfoDTO import TemplateColumnInfoDTO
from alipay.aop.api.domain.TemplateFieldRuleDTO import TemplateFieldRuleDTO
from alipay.aop.api.domain.TemplateMdcodeNotifyConfDTO import TemplateMdcodeNotifyConfDTO
from alipay.aop.api.domain.TemplateOpenCardConfDTO import TemplateOpenCardConfDTO
from alipay.aop.api.domain.PaidOuterCardTemplateConfDTO import PaidOuterCardTemplateConfDTO
from alipay.aop.api.domain.PubChannelDTO import PubChannelDTO
from alipay.aop.api.domain.TemplateBenefitInfoDTO import TemplateBenefitInfoDTO
from alipay.aop.api.domain.TemplateStyleInfoDTO import TemplateStyleInfoDTO


class AlipayMarketingCardTemplateModifyModel(object):

    def __init__(self):
        self._biz_no_prefix = None
        self._biz_no_suffix_len = None
        self._card_action_list = None
        self._card_level_conf = None
        self._card_spec_tag = None
        self._column_info_list = None
        self._field_rule_list = None
        self._mdcode_notify_conf = None
        self._open_card_conf = None
        self._paid_outer_card_conf = None
        self._pub_channels = None
        self._request_id = None
        self._shop_ids = None
        self._spi_app_id = None
        self._template_benefit_info = None
        self._template_id = None
        self._template_style_info = None
        self._write_off_type = None

    @property
    def biz_no_prefix(self):
        return self._biz_no_prefix

    @biz_no_prefix.setter
    def biz_no_prefix(self, value):
        self._biz_no_prefix = value
    @property
    def biz_no_suffix_len(self):
        return self._biz_no_suffix_len

    @biz_no_suffix_len.setter
    def biz_no_suffix_len(self, value):
        self._biz_no_suffix_len = value
    @property
    def card_action_list(self):
        return self._card_action_list

    @card_action_list.setter
    def card_action_list(self, value):
        if isinstance(value, list):
            self._card_action_list = list()
            for i in value:
                if isinstance(i, TemplateActionInfoDTO):
                    self._card_action_list.append(i)
                else:
                    self._card_action_list.append(TemplateActionInfoDTO.from_alipay_dict(i))
    @property
    def card_level_conf(self):
        return self._card_level_conf

    @card_level_conf.setter
    def card_level_conf(self, value):
        if isinstance(value, list):
            self._card_level_conf = list()
            for i in value:
                if isinstance(i, TemplateCardLevelConfDTO):
                    self._card_level_conf.append(i)
                else:
                    self._card_level_conf.append(TemplateCardLevelConfDTO.from_alipay_dict(i))
    @property
    def card_spec_tag(self):
        return self._card_spec_tag

    @card_spec_tag.setter
    def card_spec_tag(self, value):
        self._card_spec_tag = value
    @property
    def column_info_list(self):
        return self._column_info_list

    @column_info_list.setter
    def column_info_list(self, value):
        if isinstance(value, list):
            self._column_info_list = list()
            for i in value:
                if isinstance(i, TemplateColumnInfoDTO):
                    self._column_info_list.append(i)
                else:
                    self._column_info_list.append(TemplateColumnInfoDTO.from_alipay_dict(i))
    @property
    def field_rule_list(self):
        return self._field_rule_list

    @field_rule_list.setter
    def field_rule_list(self, value):
        if isinstance(value, list):
            self._field_rule_list = list()
            for i in value:
                if isinstance(i, TemplateFieldRuleDTO):
                    self._field_rule_list.append(i)
                else:
                    self._field_rule_list.append(TemplateFieldRuleDTO.from_alipay_dict(i))
    @property
    def mdcode_notify_conf(self):
        return self._mdcode_notify_conf

    @mdcode_notify_conf.setter
    def mdcode_notify_conf(self, value):
        if isinstance(value, TemplateMdcodeNotifyConfDTO):
            self._mdcode_notify_conf = value
        else:
            self._mdcode_notify_conf = TemplateMdcodeNotifyConfDTO.from_alipay_dict(value)
    @property
    def open_card_conf(self):
        return self._open_card_conf

    @open_card_conf.setter
    def open_card_conf(self, value):
        if isinstance(value, TemplateOpenCardConfDTO):
            self._open_card_conf = value
        else:
            self._open_card_conf = TemplateOpenCardConfDTO.from_alipay_dict(value)
    @property
    def paid_outer_card_conf(self):
        return self._paid_outer_card_conf

    @paid_outer_card_conf.setter
    def paid_outer_card_conf(self, value):
        if isinstance(value, PaidOuterCardTemplateConfDTO):
            self._paid_outer_card_conf = value
        else:
            self._paid_outer_card_conf = PaidOuterCardTemplateConfDTO.from_alipay_dict(value)
    @property
    def pub_channels(self):
        return self._pub_channels

    @pub_channels.setter
    def pub_channels(self, value):
        if isinstance(value, list):
            self._pub_channels = list()
            for i in value:
                if isinstance(i, PubChannelDTO):
                    self._pub_channels.append(i)
                else:
                    self._pub_channels.append(PubChannelDTO.from_alipay_dict(i))
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        if isinstance(value, list):
            self._shop_ids = list()
            for i in value:
                self._shop_ids.append(i)
    @property
    def spi_app_id(self):
        return self._spi_app_id

    @spi_app_id.setter
    def spi_app_id(self, value):
        self._spi_app_id = value
    @property
    def template_benefit_info(self):
        return self._template_benefit_info

    @template_benefit_info.setter
    def template_benefit_info(self, value):
        if isinstance(value, list):
            self._template_benefit_info = list()
            for i in value:
                if isinstance(i, TemplateBenefitInfoDTO):
                    self._template_benefit_info.append(i)
                else:
                    self._template_benefit_info.append(TemplateBenefitInfoDTO.from_alipay_dict(i))
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def template_style_info(self):
        return self._template_style_info

    @template_style_info.setter
    def template_style_info(self, value):
        if isinstance(value, TemplateStyleInfoDTO):
            self._template_style_info = value
        else:
            self._template_style_info = TemplateStyleInfoDTO.from_alipay_dict(value)
    @property
    def write_off_type(self):
        return self._write_off_type

    @write_off_type.setter
    def write_off_type(self, value):
        self._write_off_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_no_prefix:
            if hasattr(self.biz_no_prefix, 'to_alipay_dict'):
                params['biz_no_prefix'] = self.biz_no_prefix.to_alipay_dict()
            else:
                params['biz_no_prefix'] = self.biz_no_prefix
        if self.biz_no_suffix_len:
            if hasattr(self.biz_no_suffix_len, 'to_alipay_dict'):
                params['biz_no_suffix_len'] = self.biz_no_suffix_len.to_alipay_dict()
            else:
                params['biz_no_suffix_len'] = self.biz_no_suffix_len
        if self.card_action_list:
            if isinstance(self.card_action_list, list):
                for i in range(0, len(self.card_action_list)):
                    element = self.card_action_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.card_action_list[i] = element.to_alipay_dict()
            if hasattr(self.card_action_list, 'to_alipay_dict'):
                params['card_action_list'] = self.card_action_list.to_alipay_dict()
            else:
                params['card_action_list'] = self.card_action_list
        if self.card_level_conf:
            if isinstance(self.card_level_conf, list):
                for i in range(0, len(self.card_level_conf)):
                    element = self.card_level_conf[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.card_level_conf[i] = element.to_alipay_dict()
            if hasattr(self.card_level_conf, 'to_alipay_dict'):
                params['card_level_conf'] = self.card_level_conf.to_alipay_dict()
            else:
                params['card_level_conf'] = self.card_level_conf
        if self.card_spec_tag:
            if hasattr(self.card_spec_tag, 'to_alipay_dict'):
                params['card_spec_tag'] = self.card_spec_tag.to_alipay_dict()
            else:
                params['card_spec_tag'] = self.card_spec_tag
        if self.column_info_list:
            if isinstance(self.column_info_list, list):
                for i in range(0, len(self.column_info_list)):
                    element = self.column_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.column_info_list[i] = element.to_alipay_dict()
            if hasattr(self.column_info_list, 'to_alipay_dict'):
                params['column_info_list'] = self.column_info_list.to_alipay_dict()
            else:
                params['column_info_list'] = self.column_info_list
        if self.field_rule_list:
            if isinstance(self.field_rule_list, list):
                for i in range(0, len(self.field_rule_list)):
                    element = self.field_rule_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.field_rule_list[i] = element.to_alipay_dict()
            if hasattr(self.field_rule_list, 'to_alipay_dict'):
                params['field_rule_list'] = self.field_rule_list.to_alipay_dict()
            else:
                params['field_rule_list'] = self.field_rule_list
        if self.mdcode_notify_conf:
            if hasattr(self.mdcode_notify_conf, 'to_alipay_dict'):
                params['mdcode_notify_conf'] = self.mdcode_notify_conf.to_alipay_dict()
            else:
                params['mdcode_notify_conf'] = self.mdcode_notify_conf
        if self.open_card_conf:
            if hasattr(self.open_card_conf, 'to_alipay_dict'):
                params['open_card_conf'] = self.open_card_conf.to_alipay_dict()
            else:
                params['open_card_conf'] = self.open_card_conf
        if self.paid_outer_card_conf:
            if hasattr(self.paid_outer_card_conf, 'to_alipay_dict'):
                params['paid_outer_card_conf'] = self.paid_outer_card_conf.to_alipay_dict()
            else:
                params['paid_outer_card_conf'] = self.paid_outer_card_conf
        if self.pub_channels:
            if isinstance(self.pub_channels, list):
                for i in range(0, len(self.pub_channels)):
                    element = self.pub_channels[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pub_channels[i] = element.to_alipay_dict()
            if hasattr(self.pub_channels, 'to_alipay_dict'):
                params['pub_channels'] = self.pub_channels.to_alipay_dict()
            else:
                params['pub_channels'] = self.pub_channels
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.shop_ids:
            if isinstance(self.shop_ids, list):
                for i in range(0, len(self.shop_ids)):
                    element = self.shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.shop_ids, 'to_alipay_dict'):
                params['shop_ids'] = self.shop_ids.to_alipay_dict()
            else:
                params['shop_ids'] = self.shop_ids
        if self.spi_app_id:
            if hasattr(self.spi_app_id, 'to_alipay_dict'):
                params['spi_app_id'] = self.spi_app_id.to_alipay_dict()
            else:
                params['spi_app_id'] = self.spi_app_id
        if self.template_benefit_info:
            if isinstance(self.template_benefit_info, list):
                for i in range(0, len(self.template_benefit_info)):
                    element = self.template_benefit_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.template_benefit_info[i] = element.to_alipay_dict()
            if hasattr(self.template_benefit_info, 'to_alipay_dict'):
                params['template_benefit_info'] = self.template_benefit_info.to_alipay_dict()
            else:
                params['template_benefit_info'] = self.template_benefit_info
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.template_style_info:
            if hasattr(self.template_style_info, 'to_alipay_dict'):
                params['template_style_info'] = self.template_style_info.to_alipay_dict()
            else:
                params['template_style_info'] = self.template_style_info
        if self.write_off_type:
            if hasattr(self.write_off_type, 'to_alipay_dict'):
                params['write_off_type'] = self.write_off_type.to_alipay_dict()
            else:
                params['write_off_type'] = self.write_off_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCardTemplateModifyModel()
        if 'biz_no_prefix' in d:
            o.biz_no_prefix = d['biz_no_prefix']
        if 'biz_no_suffix_len' in d:
            o.biz_no_suffix_len = d['biz_no_suffix_len']
        if 'card_action_list' in d:
            o.card_action_list = d['card_action_list']
        if 'card_level_conf' in d:
            o.card_level_conf = d['card_level_conf']
        if 'card_spec_tag' in d:
            o.card_spec_tag = d['card_spec_tag']
        if 'column_info_list' in d:
            o.column_info_list = d['column_info_list']
        if 'field_rule_list' in d:
            o.field_rule_list = d['field_rule_list']
        if 'mdcode_notify_conf' in d:
            o.mdcode_notify_conf = d['mdcode_notify_conf']
        if 'open_card_conf' in d:
            o.open_card_conf = d['open_card_conf']
        if 'paid_outer_card_conf' in d:
            o.paid_outer_card_conf = d['paid_outer_card_conf']
        if 'pub_channels' in d:
            o.pub_channels = d['pub_channels']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'shop_ids' in d:
            o.shop_ids = d['shop_ids']
        if 'spi_app_id' in d:
            o.spi_app_id = d['spi_app_id']
        if 'template_benefit_info' in d:
            o.template_benefit_info = d['template_benefit_info']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'template_style_info' in d:
            o.template_style_info = d['template_style_info']
        if 'write_off_type' in d:
            o.write_off_type = d['write_off_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SignatoryInfoMap import SignatoryInfoMap


class AlipayUserSignatoryInfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserSignatoryInfoQueryResponse, self).__init__()
        self._out_put_map = None

    @property
    def out_put_map(self):
        return self._out_put_map

    @out_put_map.setter
    def out_put_map(self, value):
        if isinstance(value, SignatoryInfoMap):
            self._out_put_map = value
        else:
            self._out_put_map = SignatoryInfoMap.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayUserSignatoryInfoQueryResponse, self).parse_response_content(response_content)
        if 'out_put_map' in response:
            self.out_put_map = response['out_put_map']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityProdCtidVerifyModel(object):

    def __init__(self):
        self._id_number = None
        self._identify_model = None
        self._picture = None
        self._user_name = None

    @property
    def id_number(self):
        return self._id_number

    @id_number.setter
    def id_number(self, value):
        self._id_number = value
    @property
    def identify_model(self):
        return self._identify_model

    @identify_model.setter
    def identify_model(self, value):
        self._identify_model = value
    @property
    def picture(self):
        return self._picture

    @picture.setter
    def picture(self, value):
        self._picture = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.id_number:
            if hasattr(self.id_number, 'to_alipay_dict'):
                params['id_number'] = self.id_number.to_alipay_dict()
            else:
                params['id_number'] = self.id_number
        if self.identify_model:
            if hasattr(self.identify_model, 'to_alipay_dict'):
                params['identify_model'] = self.identify_model.to_alipay_dict()
            else:
                params['identify_model'] = self.identify_model
        if self.picture:
            if hasattr(self.picture, 'to_alipay_dict'):
                params['picture'] = self.picture.to_alipay_dict()
            else:
                params['picture'] = self.picture
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityProdCtidVerifyModel()
        if 'id_number' in d:
            o.id_number = d['id_number']
        if 'identify_model' in d:
            o.identify_model = d['identify_model']
        if 'picture' in d:
            o.picture = d['picture']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniIsvFastregisterCreateModel(object):

    def __init__(self):
        self._app_name = None
        self._auth_notify_url = None
        self._out_order_no = None
        self._uid = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def auth_notify_url(self):
        return self._auth_notify_url

    @auth_notify_url.setter
    def auth_notify_url(self, value):
        self._auth_notify_url = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def uid(self):
        return self._uid

    @uid.setter
    def uid(self, value):
        self._uid = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.auth_notify_url:
            if hasattr(self.auth_notify_url, 'to_alipay_dict'):
                params['auth_notify_url'] = self.auth_notify_url.to_alipay_dict()
            else:
                params['auth_notify_url'] = self.auth_notify_url
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.uid:
            if hasattr(self.uid, 'to_alipay_dict'):
                params['uid'] = self.uid.to_alipay_dict()
            else:
                params['uid'] = self.uid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniIsvFastregisterCreateModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'auth_notify_url' in d:
            o.auth_notify_url = d['auth_notify_url']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'uid' in d:
            o.uid = d['uid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class Goods(object):

    def __init__(self):
        self._goods_id = None
        self._goods_name = None
        self._goods_num = None
        self._goods_pic_url = None
        self._goods_price = None
        self._goods_specs = None

    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def goods_num(self):
        return self._goods_num

    @goods_num.setter
    def goods_num(self, value):
        self._goods_num = value
    @property
    def goods_pic_url(self):
        return self._goods_pic_url

    @goods_pic_url.setter
    def goods_pic_url(self, value):
        self._goods_pic_url = value
    @property
    def goods_price(self):
        return self._goods_price

    @goods_price.setter
    def goods_price(self, value):
        self._goods_price = value
    @property
    def goods_specs(self):
        return self._goods_specs

    @goods_specs.setter
    def goods_specs(self, value):
        self._goods_specs = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.goods_num:
            if hasattr(self.goods_num, 'to_alipay_dict'):
                params['goods_num'] = self.goods_num.to_alipay_dict()
            else:
                params['goods_num'] = self.goods_num
        if self.goods_pic_url:
            if hasattr(self.goods_pic_url, 'to_alipay_dict'):
                params['goods_pic_url'] = self.goods_pic_url.to_alipay_dict()
            else:
                params['goods_pic_url'] = self.goods_pic_url
        if self.goods_price:
            if hasattr(self.goods_price, 'to_alipay_dict'):
                params['goods_price'] = self.goods_price.to_alipay_dict()
            else:
                params['goods_price'] = self.goods_price
        if self.goods_specs:
            if hasattr(self.goods_specs, 'to_alipay_dict'):
                params['goods_specs'] = self.goods_specs.to_alipay_dict()
            else:
                params['goods_specs'] = self.goods_specs
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Goods()
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'goods_num' in d:
            o.goods_num = d['goods_num']
        if 'goods_pic_url' in d:
            o.goods_pic_url = d['goods_pic_url']
        if 'goods_price' in d:
            o.goods_price = d['goods_price']
        if 'goods_specs' in d:
            o.goods_specs = d['goods_specs']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TransferAddressInfo import TransferAddressInfo


class TransferBusinessPartnerInfo(object):

    def __init__(self):
        self._business_local_name = None
        self._business_name = None
        self._logo = None
        self._logo_type = None
        self._mcc = None
        self._operation_address = None

    @property
    def business_local_name(self):
        return self._business_local_name

    @business_local_name.setter
    def business_local_name(self, value):
        self._business_local_name = value
    @property
    def business_name(self):
        return self._business_name

    @business_name.setter
    def business_name(self, value):
        self._business_name = value
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def logo_type(self):
        return self._logo_type

    @logo_type.setter
    def logo_type(self, value):
        self._logo_type = value
    @property
    def mcc(self):
        return self._mcc

    @mcc.setter
    def mcc(self, value):
        self._mcc = value
    @property
    def operation_address(self):
        return self._operation_address

    @operation_address.setter
    def operation_address(self, value):
        if isinstance(value, TransferAddressInfo):
            self._operation_address = value
        else:
            self._operation_address = TransferAddressInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.business_local_name:
            if hasattr(self.business_local_name, 'to_alipay_dict'):
                params['business_local_name'] = self.business_local_name.to_alipay_dict()
            else:
                params['business_local_name'] = self.business_local_name
        if self.business_name:
            if hasattr(self.business_name, 'to_alipay_dict'):
                params['business_name'] = self.business_name.to_alipay_dict()
            else:
                params['business_name'] = self.business_name
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.logo_type:
            if hasattr(self.logo_type, 'to_alipay_dict'):
                params['logo_type'] = self.logo_type.to_alipay_dict()
            else:
                params['logo_type'] = self.logo_type
        if self.mcc:
            if hasattr(self.mcc, 'to_alipay_dict'):
                params['mcc'] = self.mcc.to_alipay_dict()
            else:
                params['mcc'] = self.mcc
        if self.operation_address:
            if hasattr(self.operation_address, 'to_alipay_dict'):
                params['operation_address'] = self.operation_address.to_alipay_dict()
            else:
                params['operation_address'] = self.operation_address
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TransferBusinessPartnerInfo()
        if 'business_local_name' in d:
            o.business_local_name = d['business_local_name']
        if 'business_name' in d:
            o.business_name = d['business_name']
        if 'logo' in d:
            o.logo = d['logo']
        if 'logo_type' in d:
            o.logo_type = d['logo_type']
        if 'mcc' in d:
            o.mcc = d['mcc']
        if 'operation_address' in d:
            o.operation_address = d['operation_address']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PayForPrivilegePromotionPlanInfo import PayForPrivilegePromotionPlanInfo


class AlipayMerchantPayforprivilegePromotionplanCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMerchantPayforprivilegePromotionplanCreateResponse, self).__init__()
        self._promotion_plan = None

    @property
    def promotion_plan(self):
        return self._promotion_plan

    @promotion_plan.setter
    def promotion_plan(self, value):
        if isinstance(value, PayForPrivilegePromotionPlanInfo):
            self._promotion_plan = value
        else:
            self._promotion_plan = PayForPrivilegePromotionPlanInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMerchantPayforprivilegePromotionplanCreateResponse, self).parse_response_content(response_content)
        if 'promotion_plan' in response:
            self.promotion_plan = response['promotion_plan']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenIotbpaasLavidabillsumQueryModel(object):

    def __init__(self):
        self._query_date = None

    @property
    def query_date(self):
        return self._query_date

    @query_date.setter
    def query_date(self, value):
        self._query_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.query_date:
            if hasattr(self.query_date, 'to_alipay_dict'):
                params['query_date'] = self.query_date.to_alipay_dict()
            else:
                params['query_date'] = self.query_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenIotbpaasLavidabillsumQueryModel()
        if 'query_date' in d:
            o.query_date = d['query_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayAssetPointPointprodBudgetlibQueryModel(object):

    def __init__(self):
        self._budget_code = None

    @property
    def budget_code(self):
        return self._budget_code

    @budget_code.setter
    def budget_code(self, value):
        self._budget_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.budget_code:
            if hasattr(self.budget_code, 'to_alipay_dict'):
                params['budget_code'] = self.budget_code.to_alipay_dict()
            else:
                params['budget_code'] = self.budget_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayAssetPointPointprodBudgetlibQueryModel()
        if 'budget_code' in d:
            o.budget_code = d['budget_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZMGOObligationConfig(object):

    def __init__(self):
        self._benefit_url = None
        self._obligation_amount = None
        self._obligation_template = None
        self._obligation_times = None
        self._promise_type_desc = None
        self._task_progress_redirect_schema = None

    @property
    def benefit_url(self):
        return self._benefit_url

    @benefit_url.setter
    def benefit_url(self, value):
        self._benefit_url = value
    @property
    def obligation_amount(self):
        return self._obligation_amount

    @obligation_amount.setter
    def obligation_amount(self, value):
        self._obligation_amount = value
    @property
    def obligation_template(self):
        return self._obligation_template

    @obligation_template.setter
    def obligation_template(self, value):
        self._obligation_template = value
    @property
    def obligation_times(self):
        return self._obligation_times

    @obligation_times.setter
    def obligation_times(self, value):
        self._obligation_times = value
    @property
    def promise_type_desc(self):
        return self._promise_type_desc

    @promise_type_desc.setter
    def promise_type_desc(self, value):
        self._promise_type_desc = value
    @property
    def task_progress_redirect_schema(self):
        return self._task_progress_redirect_schema

    @task_progress_redirect_schema.setter
    def task_progress_redirect_schema(self, value):
        self._task_progress_redirect_schema = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_url:
            if hasattr(self.benefit_url, 'to_alipay_dict'):
                params['benefit_url'] = self.benefit_url.to_alipay_dict()
            else:
                params['benefit_url'] = self.benefit_url
        if self.obligation_amount:
            if hasattr(self.obligation_amount, 'to_alipay_dict'):
                params['obligation_amount'] = self.obligation_amount.to_alipay_dict()
            else:
                params['obligation_amount'] = self.obligation_amount
        if self.obligation_template:
            if hasattr(self.obligation_template, 'to_alipay_dict'):
                params['obligation_template'] = self.obligation_template.to_alipay_dict()
            else:
                params['obligation_template'] = self.obligation_template
        if self.obligation_times:
            if hasattr(self.obligation_times, 'to_alipay_dict'):
                params['obligation_times'] = self.obligation_times.to_alipay_dict()
            else:
                params['obligation_times'] = self.obligation_times
        if self.promise_type_desc:
            if hasattr(self.promise_type_desc, 'to_alipay_dict'):
                params['promise_type_desc'] = self.promise_type_desc.to_alipay_dict()
            else:
                params['promise_type_desc'] = self.promise_type_desc
        if self.task_progress_redirect_schema:
            if hasattr(self.task_progress_redirect_schema, 'to_alipay_dict'):
                params['task_progress_redirect_schema'] = self.task_progress_redirect_schema.to_alipay_dict()
            else:
                params['task_progress_redirect_schema'] = self.task_progress_redirect_schema
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZMGOObligationConfig()
        if 'benefit_url' in d:
            o.benefit_url = d['benefit_url']
        if 'obligation_amount' in d:
            o.obligation_amount = d['obligation_amount']
        if 'obligation_template' in d:
            o.obligation_template = d['obligation_template']
        if 'obligation_times' in d:
            o.obligation_times = d['obligation_times']
        if 'promise_type_desc' in d:
            o.promise_type_desc = d['promise_type_desc']
        if 'task_progress_redirect_schema' in d:
            o.task_progress_redirect_schema = d['task_progress_redirect_schema']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ActivityMerchantOrder import ActivityMerchantOrder


class AntMerchantExpandIndirectActivityQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandIndirectActivityQueryResponse, self).__init__()
        self._multi_result = None
        self._rate = None
        self._status = None

    @property
    def multi_result(self):
        return self._multi_result

    @multi_result.setter
    def multi_result(self, value):
        if isinstance(value, list):
            self._multi_result = list()
            for i in value:
                if isinstance(i, ActivityMerchantOrder):
                    self._multi_result.append(i)
                else:
                    self._multi_result.append(ActivityMerchantOrder.from_alipay_dict(i))
    @property
    def rate(self):
        return self._rate

    @rate.setter
    def rate(self, value):
        self._rate = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandIndirectActivityQueryResponse, self).parse_response_content(response_content)
        if 'multi_result' in response:
            self.multi_result = response['multi_result']
        if 'rate' in response:
            self.rate = response['rate']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherInventoryInfo(object):

    def __init__(self):
        self._send_count = None
        self._use_count = None

    @property
    def send_count(self):
        return self._send_count

    @send_count.setter
    def send_count(self, value):
        self._send_count = value
    @property
    def use_count(self):
        return self._use_count

    @use_count.setter
    def use_count(self, value):
        self._use_count = value


    def to_alipay_dict(self):
        params = dict()
        if self.send_count:
            if hasattr(self.send_count, 'to_alipay_dict'):
                params['send_count'] = self.send_count.to_alipay_dict()
            else:
                params['send_count'] = self.send_count
        if self.use_count:
            if hasattr(self.use_count, 'to_alipay_dict'):
                params['use_count'] = self.use_count.to_alipay_dict()
            else:
                params['use_count'] = self.use_count
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherInventoryInfo()
        if 'send_count' in d:
            o.send_count = d['send_count']
        if 'use_count' in d:
            o.use_count = d['use_count']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceOperationUserPointQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceOperationUserPointQueryResponse, self).__init__()
        self._current_point = None
        self._total_point = None

    @property
    def current_point(self):
        return self._current_point

    @current_point.setter
    def current_point(self, value):
        self._current_point = value
    @property
    def total_point(self):
        return self._total_point

    @total_point.setter
    def total_point(self, value):
        self._total_point = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceOperationUserPointQueryResponse, self).parse_response_content(response_content)
        if 'current_point' in response:
            self.current_point = response['current_point']
        if 'total_point' in response:
            self.total_point = response['total_point']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DateRuleInfo import DateRuleInfo
from alipay.aop.api.domain.HolidayRuleInfo import HolidayRuleInfo
from alipay.aop.api.domain.WeekRuleInfo import WeekRuleInfo


class VoucherUseTimeRuleInfo(object):

    def __init__(self):
        self._date_rule_info = None
        self._holiday_rule_info = None
        self._rule_type = None
        self._week_rule_info = None

    @property
    def date_rule_info(self):
        return self._date_rule_info

    @date_rule_info.setter
    def date_rule_info(self, value):
        if isinstance(value, DateRuleInfo):
            self._date_rule_info = value
        else:
            self._date_rule_info = DateRuleInfo.from_alipay_dict(value)
    @property
    def holiday_rule_info(self):
        return self._holiday_rule_info

    @holiday_rule_info.setter
    def holiday_rule_info(self, value):
        if isinstance(value, HolidayRuleInfo):
            self._holiday_rule_info = value
        else:
            self._holiday_rule_info = HolidayRuleInfo.from_alipay_dict(value)
    @property
    def rule_type(self):
        return self._rule_type

    @rule_type.setter
    def rule_type(self, value):
        self._rule_type = value
    @property
    def week_rule_info(self):
        return self._week_rule_info

    @week_rule_info.setter
    def week_rule_info(self, value):
        if isinstance(value, WeekRuleInfo):
            self._week_rule_info = value
        else:
            self._week_rule_info = WeekRuleInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.date_rule_info:
            if hasattr(self.date_rule_info, 'to_alipay_dict'):
                params['date_rule_info'] = self.date_rule_info.to_alipay_dict()
            else:
                params['date_rule_info'] = self.date_rule_info
        if self.holiday_rule_info:
            if hasattr(self.holiday_rule_info, 'to_alipay_dict'):
                params['holiday_rule_info'] = self.holiday_rule_info.to_alipay_dict()
            else:
                params['holiday_rule_info'] = self.holiday_rule_info
        if self.rule_type:
            if hasattr(self.rule_type, 'to_alipay_dict'):
                params['rule_type'] = self.rule_type.to_alipay_dict()
            else:
                params['rule_type'] = self.rule_type
        if self.week_rule_info:
            if hasattr(self.week_rule_info, 'to_alipay_dict'):
                params['week_rule_info'] = self.week_rule_info.to_alipay_dict()
            else:
                params['week_rule_info'] = self.week_rule_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherUseTimeRuleInfo()
        if 'date_rule_info' in d:
            o.date_rule_info = d['date_rule_info']
        if 'holiday_rule_info' in d:
            o.holiday_rule_info = d['holiday_rule_info']
        if 'rule_type' in d:
            o.rule_type = d['rule_type']
        if 'week_rule_info' in d:
            o.week_rule_info = d['week_rule_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RiskBizDomain(object):

    def __init__(self):
        self._code = None
        self._description = None
        self._english_name = None
        self._full_name = None
        self._name = None
        self._name_pinyin = None
        self._tnt_inst_id = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def english_name(self):
        return self._english_name

    @english_name.setter
    def english_name(self, value):
        self._english_name = value
    @property
    def full_name(self):
        return self._full_name

    @full_name.setter
    def full_name(self, value):
        self._full_name = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def name_pinyin(self):
        return self._name_pinyin

    @name_pinyin.setter
    def name_pinyin(self, value):
        self._name_pinyin = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.english_name:
            if hasattr(self.english_name, 'to_alipay_dict'):
                params['english_name'] = self.english_name.to_alipay_dict()
            else:
                params['english_name'] = self.english_name
        if self.full_name:
            if hasattr(self.full_name, 'to_alipay_dict'):
                params['full_name'] = self.full_name.to_alipay_dict()
            else:
                params['full_name'] = self.full_name
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.name_pinyin:
            if hasattr(self.name_pinyin, 'to_alipay_dict'):
                params['name_pinyin'] = self.name_pinyin.to_alipay_dict()
            else:
                params['name_pinyin'] = self.name_pinyin
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RiskBizDomain()
        if 'code' in d:
            o.code = d['code']
        if 'description' in d:
            o.description = d['description']
        if 'english_name' in d:
            o.english_name = d['english_name']
        if 'full_name' in d:
            o.full_name = d['full_name']
        if 'name' in d:
            o.name = d['name']
        if 'name_pinyin' in d:
            o.name_pinyin = d['name_pinyin']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class QuotaGradientRule(object):

    def __init__(self):
        self._score_400 = None
        self._score_450 = None
        self._score_500 = None
        self._score_550 = None
        self._score_600 = None
        self._score_650 = None
        self._score_700 = None
        self._score_750 = None
        self._score_800 = None
        self._score_850 = None
        self._score_900 = None
        self._score_950 = None

    @property
    def score_400(self):
        return self._score_400

    @score_400.setter
    def score_400(self, value):
        self._score_400 = value
    @property
    def score_450(self):
        return self._score_450

    @score_450.setter
    def score_450(self, value):
        self._score_450 = value
    @property
    def score_500(self):
        return self._score_500

    @score_500.setter
    def score_500(self, value):
        self._score_500 = value
    @property
    def score_550(self):
        return self._score_550

    @score_550.setter
    def score_550(self, value):
        self._score_550 = value
    @property
    def score_600(self):
        return self._score_600

    @score_600.setter
    def score_600(self, value):
        self._score_600 = value
    @property
    def score_650(self):
        return self._score_650

    @score_650.setter
    def score_650(self, value):
        self._score_650 = value
    @property
    def score_700(self):
        return self._score_700

    @score_700.setter
    def score_700(self, value):
        self._score_700 = value
    @property
    def score_750(self):
        return self._score_750

    @score_750.setter
    def score_750(self, value):
        self._score_750 = value
    @property
    def score_800(self):
        return self._score_800

    @score_800.setter
    def score_800(self, value):
        self._score_800 = value
    @property
    def score_850(self):
        return self._score_850

    @score_850.setter
    def score_850(self, value):
        self._score_850 = value
    @property
    def score_900(self):
        return self._score_900

    @score_900.setter
    def score_900(self, value):
        self._score_900 = value
    @property
    def score_950(self):
        return self._score_950

    @score_950.setter
    def score_950(self, value):
        self._score_950 = value


    def to_alipay_dict(self):
        params = dict()
        if self.score_400:
            if hasattr(self.score_400, 'to_alipay_dict'):
                params['score_400'] = self.score_400.to_alipay_dict()
            else:
                params['score_400'] = self.score_400
        if self.score_450:
            if hasattr(self.score_450, 'to_alipay_dict'):
                params['score_450'] = self.score_450.to_alipay_dict()
            else:
                params['score_450'] = self.score_450
        if self.score_500:
            if hasattr(self.score_500, 'to_alipay_dict'):
                params['score_500'] = self.score_500.to_alipay_dict()
            else:
                params['score_500'] = self.score_500
        if self.score_550:
            if hasattr(self.score_550, 'to_alipay_dict'):
                params['score_550'] = self.score_550.to_alipay_dict()
            else:
                params['score_550'] = self.score_550
        if self.score_600:
            if hasattr(self.score_600, 'to_alipay_dict'):
                params['score_600'] = self.score_600.to_alipay_dict()
            else:
                params['score_600'] = self.score_600
        if self.score_650:
            if hasattr(self.score_650, 'to_alipay_dict'):
                params['score_650'] = self.score_650.to_alipay_dict()
            else:
                params['score_650'] = self.score_650
        if self.score_700:
            if hasattr(self.score_700, 'to_alipay_dict'):
                params['score_700'] = self.score_700.to_alipay_dict()
            else:
                params['score_700'] = self.score_700
        if self.score_750:
            if hasattr(self.score_750, 'to_alipay_dict'):
                params['score_750'] = self.score_750.to_alipay_dict()
            else:
                params['score_750'] = self.score_750
        if self.score_800:
            if hasattr(self.score_800, 'to_alipay_dict'):
                params['score_800'] = self.score_800.to_alipay_dict()
            else:
                params['score_800'] = self.score_800
        if self.score_850:
            if hasattr(self.score_850, 'to_alipay_dict'):
                params['score_850'] = self.score_850.to_alipay_dict()
            else:
                params['score_850'] = self.score_850
        if self.score_900:
            if hasattr(self.score_900, 'to_alipay_dict'):
                params['score_900'] = self.score_900.to_alipay_dict()
            else:
                params['score_900'] = self.score_900
        if self.score_950:
            if hasattr(self.score_950, 'to_alipay_dict'):
                params['score_950'] = self.score_950.to_alipay_dict()
            else:
                params['score_950'] = self.score_950
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QuotaGradientRule()
        if 'score_400' in d:
            o.score_400 = d['score_400']
        if 'score_450' in d:
            o.score_450 = d['score_450']
        if 'score_500' in d:
            o.score_500 = d['score_500']
        if 'score_550' in d:
            o.score_550 = d['score_550']
        if 'score_600' in d:
            o.score_600 = d['score_600']
        if 'score_650' in d:
            o.score_650 = d['score_650']
        if 'score_700' in d:
            o.score_700 = d['score_700']
        if 'score_750' in d:
            o.score_750 = d['score_750']
        if 'score_800' in d:
            o.score_800 = d['score_800']
        if 'score_850' in d:
            o.score_850 = d['score_850']
        if 'score_900' in d:
            o.score_900 = d['score_900']
        if 'score_950' in d:
            o.score_950 = d['score_950']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotSdarttoolMessageSendModel(object):

    def __init__(self):
        self._bi_da = None
        self._device_query_type = None
        self._immediate_msg = None
        self._item_id = None
        self._msg_content = None
        self._msg_content_type = None
        self._msg_expire = None
        self._msg_priority = None
        self._msg_type = None
        self._service_id = None
        self._sn = None
        self._supplier_id = None

    @property
    def bi_da(self):
        return self._bi_da

    @bi_da.setter
    def bi_da(self, value):
        self._bi_da = value
    @property
    def device_query_type(self):
        return self._device_query_type

    @device_query_type.setter
    def device_query_type(self, value):
        self._device_query_type = value
    @property
    def immediate_msg(self):
        return self._immediate_msg

    @immediate_msg.setter
    def immediate_msg(self, value):
        self._immediate_msg = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def msg_content(self):
        return self._msg_content

    @msg_content.setter
    def msg_content(self, value):
        self._msg_content = value
    @property
    def msg_content_type(self):
        return self._msg_content_type

    @msg_content_type.setter
    def msg_content_type(self, value):
        self._msg_content_type = value
    @property
    def msg_expire(self):
        return self._msg_expire

    @msg_expire.setter
    def msg_expire(self, value):
        self._msg_expire = value
    @property
    def msg_priority(self):
        return self._msg_priority

    @msg_priority.setter
    def msg_priority(self, value):
        self._msg_priority = value
    @property
    def msg_type(self):
        return self._msg_type

    @msg_type.setter
    def msg_type(self, value):
        self._msg_type = value
    @property
    def service_id(self):
        return self._service_id

    @service_id.setter
    def service_id(self, value):
        self._service_id = value
    @property
    def sn(self):
        return self._sn

    @sn.setter
    def sn(self, value):
        self._sn = value
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bi_da:
            if hasattr(self.bi_da, 'to_alipay_dict'):
                params['bi_da'] = self.bi_da.to_alipay_dict()
            else:
                params['bi_da'] = self.bi_da
        if self.device_query_type:
            if hasattr(self.device_query_type, 'to_alipay_dict'):
                params['device_query_type'] = self.device_query_type.to_alipay_dict()
            else:
                params['device_query_type'] = self.device_query_type
        if self.immediate_msg:
            if hasattr(self.immediate_msg, 'to_alipay_dict'):
                params['immediate_msg'] = self.immediate_msg.to_alipay_dict()
            else:
                params['immediate_msg'] = self.immediate_msg
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.msg_content:
            if hasattr(self.msg_content, 'to_alipay_dict'):
                params['msg_content'] = self.msg_content.to_alipay_dict()
            else:
                params['msg_content'] = self.msg_content
        if self.msg_content_type:
            if hasattr(self.msg_content_type, 'to_alipay_dict'):
                params['msg_content_type'] = self.msg_content_type.to_alipay_dict()
            else:
                params['msg_content_type'] = self.msg_content_type
        if self.msg_expire:
            if hasattr(self.msg_expire, 'to_alipay_dict'):
                params['msg_expire'] = self.msg_expire.to_alipay_dict()
            else:
                params['msg_expire'] = self.msg_expire
        if self.msg_priority:
            if hasattr(self.msg_priority, 'to_alipay_dict'):
                params['msg_priority'] = self.msg_priority.to_alipay_dict()
            else:
                params['msg_priority'] = self.msg_priority
        if self.msg_type:
            if hasattr(self.msg_type, 'to_alipay_dict'):
                params['msg_type'] = self.msg_type.to_alipay_dict()
            else:
                params['msg_type'] = self.msg_type
        if self.service_id:
            if hasattr(self.service_id, 'to_alipay_dict'):
                params['service_id'] = self.service_id.to_alipay_dict()
            else:
                params['service_id'] = self.service_id
        if self.sn:
            if hasattr(self.sn, 'to_alipay_dict'):
                params['sn'] = self.sn.to_alipay_dict()
            else:
                params['sn'] = self.sn
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotSdarttoolMessageSendModel()
        if 'bi_da' in d:
            o.bi_da = d['bi_da']
        if 'device_query_type' in d:
            o.device_query_type = d['device_query_type']
        if 'immediate_msg' in d:
            o.immediate_msg = d['immediate_msg']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'msg_content' in d:
            o.msg_content = d['msg_content']
        if 'msg_content_type' in d:
            o.msg_content_type = d['msg_content_type']
        if 'msg_expire' in d:
            o.msg_expire = d['msg_expire']
        if 'msg_priority' in d:
            o.msg_priority = d['msg_priority']
        if 'msg_type' in d:
            o.msg_type = d['msg_type']
        if 'service_id' in d:
            o.service_id = d['service_id']
        if 'sn' in d:
            o.sn = d['sn']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KmsBakingSalesForecastDTO(object):

    def __init__(self):
        self._forecast_date = None
        self._forecast_level = None
        self._sku_id = None
        self._t_plus_one = None
        self._t_plus_three = None
        self._t_plus_two = None

    @property
    def forecast_date(self):
        return self._forecast_date

    @forecast_date.setter
    def forecast_date(self, value):
        self._forecast_date = value
    @property
    def forecast_level(self):
        return self._forecast_level

    @forecast_level.setter
    def forecast_level(self, value):
        self._forecast_level = value
    @property
    def sku_id(self):
        return self._sku_id

    @sku_id.setter
    def sku_id(self, value):
        self._sku_id = value
    @property
    def t_plus_one(self):
        return self._t_plus_one

    @t_plus_one.setter
    def t_plus_one(self, value):
        self._t_plus_one = value
    @property
    def t_plus_three(self):
        return self._t_plus_three

    @t_plus_three.setter
    def t_plus_three(self, value):
        self._t_plus_three = value
    @property
    def t_plus_two(self):
        return self._t_plus_two

    @t_plus_two.setter
    def t_plus_two(self, value):
        self._t_plus_two = value


    def to_alipay_dict(self):
        params = dict()
        if self.forecast_date:
            if hasattr(self.forecast_date, 'to_alipay_dict'):
                params['forecast_date'] = self.forecast_date.to_alipay_dict()
            else:
                params['forecast_date'] = self.forecast_date
        if self.forecast_level:
            if hasattr(self.forecast_level, 'to_alipay_dict'):
                params['forecast_level'] = self.forecast_level.to_alipay_dict()
            else:
                params['forecast_level'] = self.forecast_level
        if self.sku_id:
            if hasattr(self.sku_id, 'to_alipay_dict'):
                params['sku_id'] = self.sku_id.to_alipay_dict()
            else:
                params['sku_id'] = self.sku_id
        if self.t_plus_one:
            if hasattr(self.t_plus_one, 'to_alipay_dict'):
                params['t_plus_one'] = self.t_plus_one.to_alipay_dict()
            else:
                params['t_plus_one'] = self.t_plus_one
        if self.t_plus_three:
            if hasattr(self.t_plus_three, 'to_alipay_dict'):
                params['t_plus_three'] = self.t_plus_three.to_alipay_dict()
            else:
                params['t_plus_three'] = self.t_plus_three
        if self.t_plus_two:
            if hasattr(self.t_plus_two, 'to_alipay_dict'):
                params['t_plus_two'] = self.t_plus_two.to_alipay_dict()
            else:
                params['t_plus_two'] = self.t_plus_two
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KmsBakingSalesForecastDTO()
        if 'forecast_date' in d:
            o.forecast_date = d['forecast_date']
        if 'forecast_level' in d:
            o.forecast_level = d['forecast_level']
        if 'sku_id' in d:
            o.sku_id = d['sku_id']
        if 't_plus_one' in d:
            o.t_plus_one = d['t_plus_one']
        if 't_plus_three' in d:
            o.t_plus_three = d['t_plus_three']
        if 't_plus_two' in d:
            o.t_plus_two = d['t_plus_two']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Paginator import Paginator


class AlipayMarketingCampaignPromotionactivityMerchantviewBatchqueryModel(object):

    def __init__(self):
        self._goods_ids = None
        self._merchant_pid = None
        self._only_current_isv = None
        self._paginator = None

    @property
    def goods_ids(self):
        return self._goods_ids

    @goods_ids.setter
    def goods_ids(self, value):
        if isinstance(value, list):
            self._goods_ids = list()
            for i in value:
                self._goods_ids.append(i)
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def only_current_isv(self):
        return self._only_current_isv

    @only_current_isv.setter
    def only_current_isv(self, value):
        self._only_current_isv = value
    @property
    def paginator(self):
        return self._paginator

    @paginator.setter
    def paginator(self, value):
        if isinstance(value, Paginator):
            self._paginator = value
        else:
            self._paginator = Paginator.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.goods_ids:
            if isinstance(self.goods_ids, list):
                for i in range(0, len(self.goods_ids)):
                    element = self.goods_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_ids[i] = element.to_alipay_dict()
            if hasattr(self.goods_ids, 'to_alipay_dict'):
                params['goods_ids'] = self.goods_ids.to_alipay_dict()
            else:
                params['goods_ids'] = self.goods_ids
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.only_current_isv:
            if hasattr(self.only_current_isv, 'to_alipay_dict'):
                params['only_current_isv'] = self.only_current_isv.to_alipay_dict()
            else:
                params['only_current_isv'] = self.only_current_isv
        if self.paginator:
            if hasattr(self.paginator, 'to_alipay_dict'):
                params['paginator'] = self.paginator.to_alipay_dict()
            else:
                params['paginator'] = self.paginator
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignPromotionactivityMerchantviewBatchqueryModel()
        if 'goods_ids' in d:
            o.goods_ids = d['goods_ids']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'only_current_isv' in d:
            o.only_current_isv = d['only_current_isv']
        if 'paginator' in d:
            o.paginator = d['paginator']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateCampusInstitutionsAddModel(object):

    def __init__(self):
        self._card_pict_url = None
        self._city_code = None
        self._inst_name = None
        self._inst_std_code = None
        self._learning_stage = None
        self._province_code = None
        self._school_property = None

    @property
    def card_pict_url(self):
        return self._card_pict_url

    @card_pict_url.setter
    def card_pict_url(self, value):
        self._card_pict_url = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def inst_name(self):
        return self._inst_name

    @inst_name.setter
    def inst_name(self, value):
        self._inst_name = value
    @property
    def inst_std_code(self):
        return self._inst_std_code

    @inst_std_code.setter
    def inst_std_code(self, value):
        self._inst_std_code = value
    @property
    def learning_stage(self):
        return self._learning_stage

    @learning_stage.setter
    def learning_stage(self, value):
        self._learning_stage = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def school_property(self):
        return self._school_property

    @school_property.setter
    def school_property(self, value):
        self._school_property = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_pict_url:
            if hasattr(self.card_pict_url, 'to_alipay_dict'):
                params['card_pict_url'] = self.card_pict_url.to_alipay_dict()
            else:
                params['card_pict_url'] = self.card_pict_url
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.inst_name:
            if hasattr(self.inst_name, 'to_alipay_dict'):
                params['inst_name'] = self.inst_name.to_alipay_dict()
            else:
                params['inst_name'] = self.inst_name
        if self.inst_std_code:
            if hasattr(self.inst_std_code, 'to_alipay_dict'):
                params['inst_std_code'] = self.inst_std_code.to_alipay_dict()
            else:
                params['inst_std_code'] = self.inst_std_code
        if self.learning_stage:
            if hasattr(self.learning_stage, 'to_alipay_dict'):
                params['learning_stage'] = self.learning_stage.to_alipay_dict()
            else:
                params['learning_stage'] = self.learning_stage
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.school_property:
            if hasattr(self.school_property, 'to_alipay_dict'):
                params['school_property'] = self.school_property.to_alipay_dict()
            else:
                params['school_property'] = self.school_property
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateCampusInstitutionsAddModel()
        if 'card_pict_url' in d:
            o.card_pict_url = d['card_pict_url']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'inst_name' in d:
            o.inst_name = d['inst_name']
        if 'inst_std_code' in d:
            o.inst_std_code = d['inst_std_code']
        if 'learning_stage' in d:
            o.learning_stage = d['learning_stage']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'school_property' in d:
            o.school_property = d['school_property']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PosOrderKey import PosOrderKey


class KoubeiCateringOrderBillCancelModel(object):

    def __init__(self):
        self._action = None
        self._cancel_time = None
        self._pos_order_key = None

    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def cancel_time(self):
        return self._cancel_time

    @cancel_time.setter
    def cancel_time(self, value):
        self._cancel_time = value
    @property
    def pos_order_key(self):
        return self._pos_order_key

    @pos_order_key.setter
    def pos_order_key(self, value):
        if isinstance(value, PosOrderKey):
            self._pos_order_key = value
        else:
            self._pos_order_key = PosOrderKey.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.cancel_time:
            if hasattr(self.cancel_time, 'to_alipay_dict'):
                params['cancel_time'] = self.cancel_time.to_alipay_dict()
            else:
                params['cancel_time'] = self.cancel_time
        if self.pos_order_key:
            if hasattr(self.pos_order_key, 'to_alipay_dict'):
                params['pos_order_key'] = self.pos_order_key.to_alipay_dict()
            else:
                params['pos_order_key'] = self.pos_order_key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringOrderBillCancelModel()
        if 'action' in d:
            o.action = d['action']
        if 'cancel_time' in d:
            o.cancel_time = d['cancel_time']
        if 'pos_order_key' in d:
            o.pos_order_key = d['pos_order_key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ExtUserInfo(object):

    def __init__(self):
        self._cert_no = None
        self._cert_type = None
        self._fix_buyer = None
        self._identity_hash = None
        self._min_age = None
        self._mobile = None
        self._name = None
        self._need_check_info = None

    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def fix_buyer(self):
        return self._fix_buyer

    @fix_buyer.setter
    def fix_buyer(self, value):
        self._fix_buyer = value
    @property
    def identity_hash(self):
        return self._identity_hash

    @identity_hash.setter
    def identity_hash(self, value):
        self._identity_hash = value
    @property
    def min_age(self):
        return self._min_age

    @min_age.setter
    def min_age(self, value):
        self._min_age = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def need_check_info(self):
        return self._need_check_info

    @need_check_info.setter
    def need_check_info(self, value):
        self._need_check_info = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.fix_buyer:
            if hasattr(self.fix_buyer, 'to_alipay_dict'):
                params['fix_buyer'] = self.fix_buyer.to_alipay_dict()
            else:
                params['fix_buyer'] = self.fix_buyer
        if self.identity_hash:
            if hasattr(self.identity_hash, 'to_alipay_dict'):
                params['identity_hash'] = self.identity_hash.to_alipay_dict()
            else:
                params['identity_hash'] = self.identity_hash
        if self.min_age:
            if hasattr(self.min_age, 'to_alipay_dict'):
                params['min_age'] = self.min_age.to_alipay_dict()
            else:
                params['min_age'] = self.min_age
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.need_check_info:
            if hasattr(self.need_check_info, 'to_alipay_dict'):
                params['need_check_info'] = self.need_check_info.to_alipay_dict()
            else:
                params['need_check_info'] = self.need_check_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExtUserInfo()
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'fix_buyer' in d:
            o.fix_buyer = d['fix_buyer']
        if 'identity_hash' in d:
            o.identity_hash = d['identity_hash']
        if 'min_age' in d:
            o.min_age = d['min_age']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'name' in d:
            o.name = d['name']
        if 'need_check_info' in d:
            o.need_check_info = d['need_check_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppIndustryOnecodepassOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppIndustryOnecodepassOrderQueryResponse, self).__init__()
        self._buyer_pay_amount = None
        self._org_buyer_openid = None
        self._org_buyer_unionid = None
        self._out_trade_no = None
        self._status = None
        self._total_amount = None
        self._trade_no = None

    @property
    def buyer_pay_amount(self):
        return self._buyer_pay_amount

    @buyer_pay_amount.setter
    def buyer_pay_amount(self, value):
        self._buyer_pay_amount = value
    @property
    def org_buyer_openid(self):
        return self._org_buyer_openid

    @org_buyer_openid.setter
    def org_buyer_openid(self, value):
        self._org_buyer_openid = value
    @property
    def org_buyer_unionid(self):
        return self._org_buyer_unionid

    @org_buyer_unionid.setter
    def org_buyer_unionid(self, value):
        self._org_buyer_unionid = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppIndustryOnecodepassOrderQueryResponse, self).parse_response_content(response_content)
        if 'buyer_pay_amount' in response:
            self.buyer_pay_amount = response['buyer_pay_amount']
        if 'org_buyer_openid' in response:
            self.org_buyer_openid = response['org_buyer_openid']
        if 'org_buyer_unionid' in response:
            self.org_buyer_unionid = response['org_buyer_unionid']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'status' in response:
            self.status = response['status']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PintuanUserInfo import PintuanUserInfo


class PintuanUserInfos(object):

    def __init__(self):
        self._pintuan_user_info_list = None

    @property
    def pintuan_user_info_list(self):
        return self._pintuan_user_info_list

    @pintuan_user_info_list.setter
    def pintuan_user_info_list(self, value):
        if isinstance(value, PintuanUserInfo):
            self._pintuan_user_info_list = value
        else:
            self._pintuan_user_info_list = PintuanUserInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.pintuan_user_info_list:
            if hasattr(self.pintuan_user_info_list, 'to_alipay_dict'):
                params['pintuan_user_info_list'] = self.pintuan_user_info_list.to_alipay_dict()
            else:
                params['pintuan_user_info_list'] = self.pintuan_user_info_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PintuanUserInfos()
        if 'pintuan_user_info_list' in d:
            o.pintuan_user_info_list = d['pintuan_user_info_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TagRuleGroupDTO import TagRuleGroupDTO


class DatadigitalFincloudFinsaasTagcrowdCountQueryModel(object):

    def __init__(self):
        self._rules = None
        self._scene_code = None

    @property
    def rules(self):
        return self._rules

    @rules.setter
    def rules(self, value):
        if isinstance(value, list):
            self._rules = list()
            for i in value:
                if isinstance(i, TagRuleGroupDTO):
                    self._rules.append(i)
                else:
                    self._rules.append(TagRuleGroupDTO.from_alipay_dict(i))
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.rules:
            if isinstance(self.rules, list):
                for i in range(0, len(self.rules)):
                    element = self.rules[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.rules[i] = element.to_alipay_dict()
            if hasattr(self.rules, 'to_alipay_dict'):
                params['rules'] = self.rules.to_alipay_dict()
            else:
                params['rules'] = self.rules
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DatadigitalFincloudFinsaasTagcrowdCountQueryModel()
        if 'rules' in d:
            o.rules = d['rules']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MiniAppBaseInfoQueryResponse import MiniAppBaseInfoQueryResponse


class AlipayOpenMiniDeveloperAppinfoBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniDeveloperAppinfoBatchqueryResponse, self).__init__()
        self._app_base_info_list = None

    @property
    def app_base_info_list(self):
        return self._app_base_info_list

    @app_base_info_list.setter
    def app_base_info_list(self, value):
        if isinstance(value, list):
            self._app_base_info_list = list()
            for i in value:
                if isinstance(i, MiniAppBaseInfoQueryResponse):
                    self._app_base_info_list.append(i)
                else:
                    self._app_base_info_list.append(MiniAppBaseInfoQueryResponse.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniDeveloperAppinfoBatchqueryResponse, self).parse_response_content(response_content)
        if 'app_base_info_list' in response:
            self.app_base_info_list = response['app_base_info_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MedicalHospitalOrderUploadResult(object):

    def __init__(self):
        self._order_id_list = None
        self._out_biz_no = None
        self._trace_id = None

    @property
    def order_id_list(self):
        return self._order_id_list

    @order_id_list.setter
    def order_id_list(self, value):
        if isinstance(value, list):
            self._order_id_list = list()
            for i in value:
                self._order_id_list.append(i)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.order_id_list:
            if isinstance(self.order_id_list, list):
                for i in range(0, len(self.order_id_list)):
                    element = self.order_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_id_list[i] = element.to_alipay_dict()
            if hasattr(self.order_id_list, 'to_alipay_dict'):
                params['order_id_list'] = self.order_id_list.to_alipay_dict()
            else:
                params['order_id_list'] = self.order_id_list
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MedicalHospitalOrderUploadResult()
        if 'order_id_list' in d:
            o.order_id_list = d['order_id_list']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarParkingSpaceinfoSyncModel(object):

    def __init__(self):
        self._free_charging_pile = None
        self._free_parking_space = None
        self._parking_id = None
        self._parking_space_status = None

    @property
    def free_charging_pile(self):
        return self._free_charging_pile

    @free_charging_pile.setter
    def free_charging_pile(self, value):
        self._free_charging_pile = value
    @property
    def free_parking_space(self):
        return self._free_parking_space

    @free_parking_space.setter
    def free_parking_space(self, value):
        self._free_parking_space = value
    @property
    def parking_id(self):
        return self._parking_id

    @parking_id.setter
    def parking_id(self, value):
        self._parking_id = value
    @property
    def parking_space_status(self):
        return self._parking_space_status

    @parking_space_status.setter
    def parking_space_status(self, value):
        self._parking_space_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.free_charging_pile:
            if hasattr(self.free_charging_pile, 'to_alipay_dict'):
                params['free_charging_pile'] = self.free_charging_pile.to_alipay_dict()
            else:
                params['free_charging_pile'] = self.free_charging_pile
        if self.free_parking_space:
            if hasattr(self.free_parking_space, 'to_alipay_dict'):
                params['free_parking_space'] = self.free_parking_space.to_alipay_dict()
            else:
                params['free_parking_space'] = self.free_parking_space
        if self.parking_id:
            if hasattr(self.parking_id, 'to_alipay_dict'):
                params['parking_id'] = self.parking_id.to_alipay_dict()
            else:
                params['parking_id'] = self.parking_id
        if self.parking_space_status:
            if hasattr(self.parking_space_status, 'to_alipay_dict'):
                params['parking_space_status'] = self.parking_space_status.to_alipay_dict()
            else:
                params['parking_space_status'] = self.parking_space_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingSpaceinfoSyncModel()
        if 'free_charging_pile' in d:
            o.free_charging_pile = d['free_charging_pile']
        if 'free_parking_space' in d:
            o.free_parking_space = d['free_parking_space']
        if 'parking_id' in d:
            o.parking_id = d['parking_id']
        if 'parking_space_status' in d:
            o.parking_space_status = d['parking_space_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OuterPlan(object):

    def __init__(self):
        self._budget = None
        self._budget_over_status = None
        self._charge_type = None
        self._end_date = None
        self._extend_info = None
        self._plan_id = None
        self._plan_name = None
        self._plan_outer_id = None
        self._plan_status = None
        self._principal_id = None
        self._sell_mode = None
        self._start_date = None
        self._time_schema = None
        self._user_id = None

    @property
    def budget(self):
        return self._budget

    @budget.setter
    def budget(self, value):
        self._budget = value
    @property
    def budget_over_status(self):
        return self._budget_over_status

    @budget_over_status.setter
    def budget_over_status(self, value):
        self._budget_over_status = value
    @property
    def charge_type(self):
        return self._charge_type

    @charge_type.setter
    def charge_type(self, value):
        self._charge_type = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def plan_id(self):
        return self._plan_id

    @plan_id.setter
    def plan_id(self, value):
        self._plan_id = value
    @property
    def plan_name(self):
        return self._plan_name

    @plan_name.setter
    def plan_name(self, value):
        self._plan_name = value
    @property
    def plan_outer_id(self):
        return self._plan_outer_id

    @plan_outer_id.setter
    def plan_outer_id(self, value):
        self._plan_outer_id = value
    @property
    def plan_status(self):
        return self._plan_status

    @plan_status.setter
    def plan_status(self, value):
        self._plan_status = value
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def sell_mode(self):
        return self._sell_mode

    @sell_mode.setter
    def sell_mode(self, value):
        self._sell_mode = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def time_schema(self):
        return self._time_schema

    @time_schema.setter
    def time_schema(self, value):
        self._time_schema = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.budget:
            if hasattr(self.budget, 'to_alipay_dict'):
                params['budget'] = self.budget.to_alipay_dict()
            else:
                params['budget'] = self.budget
        if self.budget_over_status:
            if hasattr(self.budget_over_status, 'to_alipay_dict'):
                params['budget_over_status'] = self.budget_over_status.to_alipay_dict()
            else:
                params['budget_over_status'] = self.budget_over_status
        if self.charge_type:
            if hasattr(self.charge_type, 'to_alipay_dict'):
                params['charge_type'] = self.charge_type.to_alipay_dict()
            else:
                params['charge_type'] = self.charge_type
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.plan_id:
            if hasattr(self.plan_id, 'to_alipay_dict'):
                params['plan_id'] = self.plan_id.to_alipay_dict()
            else:
                params['plan_id'] = self.plan_id
        if self.plan_name:
            if hasattr(self.plan_name, 'to_alipay_dict'):
                params['plan_name'] = self.plan_name.to_alipay_dict()
            else:
                params['plan_name'] = self.plan_name
        if self.plan_outer_id:
            if hasattr(self.plan_outer_id, 'to_alipay_dict'):
                params['plan_outer_id'] = self.plan_outer_id.to_alipay_dict()
            else:
                params['plan_outer_id'] = self.plan_outer_id
        if self.plan_status:
            if hasattr(self.plan_status, 'to_alipay_dict'):
                params['plan_status'] = self.plan_status.to_alipay_dict()
            else:
                params['plan_status'] = self.plan_status
        if self.principal_id:
            if hasattr(self.principal_id, 'to_alipay_dict'):
                params['principal_id'] = self.principal_id.to_alipay_dict()
            else:
                params['principal_id'] = self.principal_id
        if self.sell_mode:
            if hasattr(self.sell_mode, 'to_alipay_dict'):
                params['sell_mode'] = self.sell_mode.to_alipay_dict()
            else:
                params['sell_mode'] = self.sell_mode
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.time_schema:
            if hasattr(self.time_schema, 'to_alipay_dict'):
                params['time_schema'] = self.time_schema.to_alipay_dict()
            else:
                params['time_schema'] = self.time_schema
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OuterPlan()
        if 'budget' in d:
            o.budget = d['budget']
        if 'budget_over_status' in d:
            o.budget_over_status = d['budget_over_status']
        if 'charge_type' in d:
            o.charge_type = d['charge_type']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'plan_id' in d:
            o.plan_id = d['plan_id']
        if 'plan_name' in d:
            o.plan_name = d['plan_name']
        if 'plan_outer_id' in d:
            o.plan_outer_id = d['plan_outer_id']
        if 'plan_status' in d:
            o.plan_status = d['plan_status']
        if 'principal_id' in d:
            o.principal_id = d['principal_id']
        if 'sell_mode' in d:
            o.sell_mode = d['sell_mode']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'time_schema' in d:
            o.time_schema = d['time_schema']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeductInfo import DeductInfo


class CustomerDefineVoucherInfo(object):

    def __init__(self):
        self._deduct_info = None

    @property
    def deduct_info(self):
        return self._deduct_info

    @deduct_info.setter
    def deduct_info(self, value):
        if isinstance(value, DeductInfo):
            self._deduct_info = value
        else:
            self._deduct_info = DeductInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.deduct_info:
            if hasattr(self.deduct_info, 'to_alipay_dict'):
                params['deduct_info'] = self.deduct_info.to_alipay_dict()
            else:
                params['deduct_info'] = self.deduct_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CustomerDefineVoucherInfo()
        if 'deduct_info' in d:
            o.deduct_info = d['deduct_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RndBenefitRule(object):

    def __init__(self):
        self._max_benefit = None
        self._min_benefit = None
        self._proportion = None

    @property
    def max_benefit(self):
        return self._max_benefit

    @max_benefit.setter
    def max_benefit(self, value):
        self._max_benefit = value
    @property
    def min_benefit(self):
        return self._min_benefit

    @min_benefit.setter
    def min_benefit(self, value):
        self._min_benefit = value
    @property
    def proportion(self):
        return self._proportion

    @proportion.setter
    def proportion(self, value):
        self._proportion = value


    def to_alipay_dict(self):
        params = dict()
        if self.max_benefit:
            if hasattr(self.max_benefit, 'to_alipay_dict'):
                params['max_benefit'] = self.max_benefit.to_alipay_dict()
            else:
                params['max_benefit'] = self.max_benefit
        if self.min_benefit:
            if hasattr(self.min_benefit, 'to_alipay_dict'):
                params['min_benefit'] = self.min_benefit.to_alipay_dict()
            else:
                params['min_benefit'] = self.min_benefit
        if self.proportion:
            if hasattr(self.proportion, 'to_alipay_dict'):
                params['proportion'] = self.proportion.to_alipay_dict()
            else:
                params['proportion'] = self.proportion
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RndBenefitRule()
        if 'max_benefit' in d:
            o.max_benefit = d['max_benefit']
        if 'min_benefit' in d:
            o.min_benefit = d['min_benefit']
        if 'proportion' in d:
            o.proportion = d['proportion']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenIotClerkinspireQueryModel(object):

    def __init__(self):
        self._biz_tid = None
        self._device_sn = None
        self._item_id = None
        self._supplier_id = None

    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value
    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenIotClerkinspireQueryModel()
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MerchantModel(object):

    def __init__(self):
        self._alias_name = None
        self._contact_name = None
        self._contact_number = None
        self._name = None
        self._pid = None

    @property
    def alias_name(self):
        return self._alias_name

    @alias_name.setter
    def alias_name(self, value):
        self._alias_name = value
    @property
    def contact_name(self):
        return self._contact_name

    @contact_name.setter
    def contact_name(self, value):
        self._contact_name = value
    @property
    def contact_number(self):
        return self._contact_number

    @contact_number.setter
    def contact_number(self, value):
        self._contact_number = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.alias_name:
            if hasattr(self.alias_name, 'to_alipay_dict'):
                params['alias_name'] = self.alias_name.to_alipay_dict()
            else:
                params['alias_name'] = self.alias_name
        if self.contact_name:
            if hasattr(self.contact_name, 'to_alipay_dict'):
                params['contact_name'] = self.contact_name.to_alipay_dict()
            else:
                params['contact_name'] = self.contact_name
        if self.contact_number:
            if hasattr(self.contact_number, 'to_alipay_dict'):
                params['contact_number'] = self.contact_number.to_alipay_dict()
            else:
                params['contact_number'] = self.contact_number
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MerchantModel()
        if 'alias_name' in d:
            o.alias_name = d['alias_name']
        if 'contact_name' in d:
            o.contact_name = d['contact_name']
        if 'contact_number' in d:
            o.contact_number = d['contact_number']
        if 'name' in d:
            o.name = d['name']
        if 'pid' in d:
            o.pid = d['pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.LiveContentInfo import LiveContentInfo


class LiveInfo(object):

    def __init__(self):
        self._content_info_list = None
        self._live_end_time = None
        self._live_id = None
        self._live_start_time = None
        self._summary = None
        self._title = None

    @property
    def content_info_list(self):
        return self._content_info_list

    @content_info_list.setter
    def content_info_list(self, value):
        if isinstance(value, list):
            self._content_info_list = list()
            for i in value:
                if isinstance(i, LiveContentInfo):
                    self._content_info_list.append(i)
                else:
                    self._content_info_list.append(LiveContentInfo.from_alipay_dict(i))
    @property
    def live_end_time(self):
        return self._live_end_time

    @live_end_time.setter
    def live_end_time(self, value):
        self._live_end_time = value
    @property
    def live_id(self):
        return self._live_id

    @live_id.setter
    def live_id(self, value):
        self._live_id = value
    @property
    def live_start_time(self):
        return self._live_start_time

    @live_start_time.setter
    def live_start_time(self, value):
        self._live_start_time = value
    @property
    def summary(self):
        return self._summary

    @summary.setter
    def summary(self, value):
        self._summary = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.content_info_list:
            if isinstance(self.content_info_list, list):
                for i in range(0, len(self.content_info_list)):
                    element = self.content_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.content_info_list[i] = element.to_alipay_dict()
            if hasattr(self.content_info_list, 'to_alipay_dict'):
                params['content_info_list'] = self.content_info_list.to_alipay_dict()
            else:
                params['content_info_list'] = self.content_info_list
        if self.live_end_time:
            if hasattr(self.live_end_time, 'to_alipay_dict'):
                params['live_end_time'] = self.live_end_time.to_alipay_dict()
            else:
                params['live_end_time'] = self.live_end_time
        if self.live_id:
            if hasattr(self.live_id, 'to_alipay_dict'):
                params['live_id'] = self.live_id.to_alipay_dict()
            else:
                params['live_id'] = self.live_id
        if self.live_start_time:
            if hasattr(self.live_start_time, 'to_alipay_dict'):
                params['live_start_time'] = self.live_start_time.to_alipay_dict()
            else:
                params['live_start_time'] = self.live_start_time
        if self.summary:
            if hasattr(self.summary, 'to_alipay_dict'):
                params['summary'] = self.summary.to_alipay_dict()
            else:
                params['summary'] = self.summary
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LiveInfo()
        if 'content_info_list' in d:
            o.content_info_list = d['content_info_list']
        if 'live_end_time' in d:
            o.live_end_time = d['live_end_time']
        if 'live_id' in d:
            o.live_id = d['live_id']
        if 'live_start_time' in d:
            o.live_start_time = d['live_start_time']
        if 'summary' in d:
            o.summary = d['summary']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.QipanMerchantCrowdUser import QipanMerchantCrowdUser


class AlipayMerchantQipanCrowdCreateModel(object):

    def __init__(self):
        self._apply_channel_list = None
        self._crowd_desc = None
        self._crowd_name = None
        self._external_crowd_code = None
        self._user_list = None

    @property
    def apply_channel_list(self):
        return self._apply_channel_list

    @apply_channel_list.setter
    def apply_channel_list(self, value):
        if isinstance(value, list):
            self._apply_channel_list = list()
            for i in value:
                self._apply_channel_list.append(i)
    @property
    def crowd_desc(self):
        return self._crowd_desc

    @crowd_desc.setter
    def crowd_desc(self, value):
        self._crowd_desc = value
    @property
    def crowd_name(self):
        return self._crowd_name

    @crowd_name.setter
    def crowd_name(self, value):
        self._crowd_name = value
    @property
    def external_crowd_code(self):
        return self._external_crowd_code

    @external_crowd_code.setter
    def external_crowd_code(self, value):
        self._external_crowd_code = value
    @property
    def user_list(self):
        return self._user_list

    @user_list.setter
    def user_list(self, value):
        if isinstance(value, list):
            self._user_list = list()
            for i in value:
                if isinstance(i, QipanMerchantCrowdUser):
                    self._user_list.append(i)
                else:
                    self._user_list.append(QipanMerchantCrowdUser.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.apply_channel_list:
            if isinstance(self.apply_channel_list, list):
                for i in range(0, len(self.apply_channel_list)):
                    element = self.apply_channel_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.apply_channel_list[i] = element.to_alipay_dict()
            if hasattr(self.apply_channel_list, 'to_alipay_dict'):
                params['apply_channel_list'] = self.apply_channel_list.to_alipay_dict()
            else:
                params['apply_channel_list'] = self.apply_channel_list
        if self.crowd_desc:
            if hasattr(self.crowd_desc, 'to_alipay_dict'):
                params['crowd_desc'] = self.crowd_desc.to_alipay_dict()
            else:
                params['crowd_desc'] = self.crowd_desc
        if self.crowd_name:
            if hasattr(self.crowd_name, 'to_alipay_dict'):
                params['crowd_name'] = self.crowd_name.to_alipay_dict()
            else:
                params['crowd_name'] = self.crowd_name
        if self.external_crowd_code:
            if hasattr(self.external_crowd_code, 'to_alipay_dict'):
                params['external_crowd_code'] = self.external_crowd_code.to_alipay_dict()
            else:
                params['external_crowd_code'] = self.external_crowd_code
        if self.user_list:
            if isinstance(self.user_list, list):
                for i in range(0, len(self.user_list)):
                    element = self.user_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.user_list[i] = element.to_alipay_dict()
            if hasattr(self.user_list, 'to_alipay_dict'):
                params['user_list'] = self.user_list.to_alipay_dict()
            else:
                params['user_list'] = self.user_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantQipanCrowdCreateModel()
        if 'apply_channel_list' in d:
            o.apply_channel_list = d['apply_channel_list']
        if 'crowd_desc' in d:
            o.crowd_desc = d['crowd_desc']
        if 'crowd_name' in d:
            o.crowd_name = d['crowd_name']
        if 'external_crowd_code' in d:
            o.external_crowd_code = d['external_crowd_code']
        if 'user_list' in d:
            o.user_list = d['user_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceYuntaskRefuseModel(object):

    def __init__(self):
        self._funder_id = None
        self._funder_type = None
        self._operate_open_id = None
        self._operate_user_id = None
        self._owner_pid = None
        self._task_template_id = None

    @property
    def funder_id(self):
        return self._funder_id

    @funder_id.setter
    def funder_id(self, value):
        self._funder_id = value
    @property
    def funder_type(self):
        return self._funder_type

    @funder_type.setter
    def funder_type(self, value):
        self._funder_type = value
    @property
    def operate_open_id(self):
        return self._operate_open_id

    @operate_open_id.setter
    def operate_open_id(self, value):
        self._operate_open_id = value
    @property
    def operate_user_id(self):
        return self._operate_user_id

    @operate_user_id.setter
    def operate_user_id(self, value):
        self._operate_user_id = value
    @property
    def owner_pid(self):
        return self._owner_pid

    @owner_pid.setter
    def owner_pid(self, value):
        self._owner_pid = value
    @property
    def task_template_id(self):
        return self._task_template_id

    @task_template_id.setter
    def task_template_id(self, value):
        self._task_template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.funder_id:
            if hasattr(self.funder_id, 'to_alipay_dict'):
                params['funder_id'] = self.funder_id.to_alipay_dict()
            else:
                params['funder_id'] = self.funder_id
        if self.funder_type:
            if hasattr(self.funder_type, 'to_alipay_dict'):
                params['funder_type'] = self.funder_type.to_alipay_dict()
            else:
                params['funder_type'] = self.funder_type
        if self.operate_open_id:
            if hasattr(self.operate_open_id, 'to_alipay_dict'):
                params['operate_open_id'] = self.operate_open_id.to_alipay_dict()
            else:
                params['operate_open_id'] = self.operate_open_id
        if self.operate_user_id:
            if hasattr(self.operate_user_id, 'to_alipay_dict'):
                params['operate_user_id'] = self.operate_user_id.to_alipay_dict()
            else:
                params['operate_user_id'] = self.operate_user_id
        if self.owner_pid:
            if hasattr(self.owner_pid, 'to_alipay_dict'):
                params['owner_pid'] = self.owner_pid.to_alipay_dict()
            else:
                params['owner_pid'] = self.owner_pid
        if self.task_template_id:
            if hasattr(self.task_template_id, 'to_alipay_dict'):
                params['task_template_id'] = self.task_template_id.to_alipay_dict()
            else:
                params['task_template_id'] = self.task_template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceYuntaskRefuseModel()
        if 'funder_id' in d:
            o.funder_id = d['funder_id']
        if 'funder_type' in d:
            o.funder_type = d['funder_type']
        if 'operate_open_id' in d:
            o.operate_open_id = d['operate_open_id']
        if 'operate_user_id' in d:
            o.operate_user_id = d['operate_user_id']
        if 'owner_pid' in d:
            o.owner_pid = d['owner_pid']
        if 'task_template_id' in d:
            o.task_template_id = d['task_template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityProdTianwutestModifyModel(object):

    def __init__(self):
        self._tianwutest = None

    @property
    def tianwutest(self):
        return self._tianwutest

    @tianwutest.setter
    def tianwutest(self, value):
        self._tianwutest = value


    def to_alipay_dict(self):
        params = dict()
        if self.tianwutest:
            if hasattr(self.tianwutest, 'to_alipay_dict'):
                params['tianwutest'] = self.tianwutest.to_alipay_dict()
            else:
                params['tianwutest'] = self.tianwutest
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityProdTianwutestModifyModel()
        if 'tianwutest' in d:
            o.tianwutest = d['tianwutest']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DatadigitalAnttechQqqCccQueryModel(object):

    def __init__(self):
        self._babab = None
        self._er_1_openid = None
        self._pppp = None
        self._province_code = None
        self._re = None

    @property
    def babab(self):
        return self._babab

    @babab.setter
    def babab(self, value):
        self._babab = value
    @property
    def er_1_openid(self):
        return self._er_1_openid

    @er_1_openid.setter
    def er_1_openid(self, value):
        self._er_1_openid = value
    @property
    def pppp(self):
        return self._pppp

    @pppp.setter
    def pppp(self, value):
        self._pppp = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def re(self):
        return self._re

    @re.setter
    def re(self, value):
        self._re = value


    def to_alipay_dict(self):
        params = dict()
        if self.babab:
            if hasattr(self.babab, 'to_alipay_dict'):
                params['babab'] = self.babab.to_alipay_dict()
            else:
                params['babab'] = self.babab
        if self.er_1_openid:
            if hasattr(self.er_1_openid, 'to_alipay_dict'):
                params['er_1_openid'] = self.er_1_openid.to_alipay_dict()
            else:
                params['er_1_openid'] = self.er_1_openid
        if self.pppp:
            if hasattr(self.pppp, 'to_alipay_dict'):
                params['pppp'] = self.pppp.to_alipay_dict()
            else:
                params['pppp'] = self.pppp
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.re:
            if hasattr(self.re, 'to_alipay_dict'):
                params['re'] = self.re.to_alipay_dict()
            else:
                params['re'] = self.re
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DatadigitalAnttechQqqCccQueryModel()
        if 'babab' in d:
            o.babab = d['babab']
        if 'er_1_openid' in d:
            o.er_1_openid = d['er_1_openid']
        if 'pppp' in d:
            o.pppp = d['pppp']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 're' in d:
            o.re = d['re']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CampusCardPicture(object):

    def __init__(self):
        self._picture_type = None
        self._url = None

    @property
    def picture_type(self):
        return self._picture_type

    @picture_type.setter
    def picture_type(self, value):
        self._picture_type = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value


    def to_alipay_dict(self):
        params = dict()
        if self.picture_type:
            if hasattr(self.picture_type, 'to_alipay_dict'):
                params['picture_type'] = self.picture_type.to_alipay_dict()
            else:
                params['picture_type'] = self.picture_type
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CampusCardPicture()
        if 'picture_type' in d:
            o.picture_type = d['picture_type']
        if 'url' in d:
            o.url = d['url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAuthUserauthTokenCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAuthUserauthTokenCreateResponse, self).__init__()
        self._auth_start = None
        self._auth_token = None
        self._expires_in = None
        self._re_expires_in = None
        self._refresh_token = None

    @property
    def auth_start(self):
        return self._auth_start

    @auth_start.setter
    def auth_start(self, value):
        self._auth_start = value
    @property
    def auth_token(self):
        return self._auth_token

    @auth_token.setter
    def auth_token(self, value):
        self._auth_token = value
    @property
    def expires_in(self):
        return self._expires_in

    @expires_in.setter
    def expires_in(self, value):
        self._expires_in = value
    @property
    def re_expires_in(self):
        return self._re_expires_in

    @re_expires_in.setter
    def re_expires_in(self, value):
        self._re_expires_in = value
    @property
    def refresh_token(self):
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, value):
        self._refresh_token = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAuthUserauthTokenCreateResponse, self).parse_response_content(response_content)
        if 'auth_start' in response:
            self.auth_start = response['auth_start']
        if 'auth_token' in response:
            self.auth_token = response['auth_token']
        if 'expires_in' in response:
            self.expires_in = response['expires_in']
        if 're_expires_in' in response:
            self.re_expires_in = response['re_expires_in']
        if 'refresh_token' in response:
            self.refresh_token = response['refresh_token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.UserIdentity import UserIdentity
from alipay.aop.api.domain.OrderExtInfo import OrderExtInfo
from alipay.aop.api.domain.GoodsInformation import GoodsInformation
from alipay.aop.api.domain.PriceInformation import PriceInformation
from alipay.aop.api.domain.PaymentInformation import PaymentInformation
from alipay.aop.api.domain.UserIdentity import UserIdentity


class AlipayMerchantOrderCreateandpayModel(object):

    def __init__(self):
        self._biz_scene = None
        self._buyer = None
        self._ext_info = None
        self._goods_infos = None
        self._order_amount = None
        self._out_biz_no = None
        self._payment_request = None
        self._seller = None
        self._service_type = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def buyer(self):
        return self._buyer

    @buyer.setter
    def buyer(self, value):
        if isinstance(value, UserIdentity):
            self._buyer = value
        else:
            self._buyer = UserIdentity.from_alipay_dict(value)
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, OrderExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(OrderExtInfo.from_alipay_dict(i))
    @property
    def goods_infos(self):
        return self._goods_infos

    @goods_infos.setter
    def goods_infos(self, value):
        if isinstance(value, list):
            self._goods_infos = list()
            for i in value:
                if isinstance(i, GoodsInformation):
                    self._goods_infos.append(i)
                else:
                    self._goods_infos.append(GoodsInformation.from_alipay_dict(i))
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        if isinstance(value, list):
            self._order_amount = list()
            for i in value:
                if isinstance(i, PriceInformation):
                    self._order_amount.append(i)
                else:
                    self._order_amount.append(PriceInformation.from_alipay_dict(i))
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def payment_request(self):
        return self._payment_request

    @payment_request.setter
    def payment_request(self, value):
        if isinstance(value, list):
            self._payment_request = list()
            for i in value:
                if isinstance(i, PaymentInformation):
                    self._payment_request.append(i)
                else:
                    self._payment_request.append(PaymentInformation.from_alipay_dict(i))
    @property
    def seller(self):
        return self._seller

    @seller.setter
    def seller(self, value):
        if isinstance(value, UserIdentity):
            self._seller = value
        else:
            self._seller = UserIdentity.from_alipay_dict(value)
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.buyer:
            if hasattr(self.buyer, 'to_alipay_dict'):
                params['buyer'] = self.buyer.to_alipay_dict()
            else:
                params['buyer'] = self.buyer
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.goods_infos:
            if isinstance(self.goods_infos, list):
                for i in range(0, len(self.goods_infos)):
                    element = self.goods_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_infos[i] = element.to_alipay_dict()
            if hasattr(self.goods_infos, 'to_alipay_dict'):
                params['goods_infos'] = self.goods_infos.to_alipay_dict()
            else:
                params['goods_infos'] = self.goods_infos
        if self.order_amount:
            if isinstance(self.order_amount, list):
                for i in range(0, len(self.order_amount)):
                    element = self.order_amount[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_amount[i] = element.to_alipay_dict()
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = self.order_amount.to_alipay_dict()
            else:
                params['order_amount'] = self.order_amount
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.payment_request:
            if isinstance(self.payment_request, list):
                for i in range(0, len(self.payment_request)):
                    element = self.payment_request[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.payment_request[i] = element.to_alipay_dict()
            if hasattr(self.payment_request, 'to_alipay_dict'):
                params['payment_request'] = self.payment_request.to_alipay_dict()
            else:
                params['payment_request'] = self.payment_request
        if self.seller:
            if hasattr(self.seller, 'to_alipay_dict'):
                params['seller'] = self.seller.to_alipay_dict()
            else:
                params['seller'] = self.seller
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantOrderCreateandpayModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'buyer' in d:
            o.buyer = d['buyer']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'goods_infos' in d:
            o.goods_infos = d['goods_infos']
        if 'order_amount' in d:
            o.order_amount = d['order_amount']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'payment_request' in d:
            o.payment_request = d['payment_request']
        if 'seller' in d:
            o.seller = d['seller']
        if 'service_type' in d:
            o.service_type = d['service_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataBillEreceiptagentApplyModel(object):

    def __init__(self):
        self._agreement_no = None
        self._key = None
        self._type = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def key(self):
        return self._key

    @key.setter
    def key(self, value):
        self._key = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.key:
            if hasattr(self.key, 'to_alipay_dict'):
                params['key'] = self.key.to_alipay_dict()
            else:
                params['key'] = self.key
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataBillEreceiptagentApplyModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'key' in d:
            o.key = d['key']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenLotteryCampSubmitModel(object):

    def __init__(self):
        self._env = None

    @property
    def env(self):
        return self._env

    @env.setter
    def env(self, value):
        self._env = value


    def to_alipay_dict(self):
        params = dict()
        if self.env:
            if hasattr(self.env, 'to_alipay_dict'):
                params['env'] = self.env.to_alipay_dict()
            else:
                params['env'] = self.env
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenLotteryCampSubmitModel()
        if 'env' in d:
            o.env = d['env']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GravityParam import GravityParam
from alipay.aop.api.domain.SecGravityServiceHeader import SecGravityServiceHeader
from alipay.aop.api.domain.GravityParam import GravityParam


class AlipaySecurityRiskGravityConsultModel(object):

    def __init__(self):
        self._authorized_client_id = None
        self._extension = None
        self._header = None
        self._params = None
        self._product_id = None
        self._session_token = None

    @property
    def authorized_client_id(self):
        return self._authorized_client_id

    @authorized_client_id.setter
    def authorized_client_id(self, value):
        self._authorized_client_id = value
    @property
    def extension(self):
        return self._extension

    @extension.setter
    def extension(self, value):
        if isinstance(value, list):
            self._extension = list()
            for i in value:
                if isinstance(i, GravityParam):
                    self._extension.append(i)
                else:
                    self._extension.append(GravityParam.from_alipay_dict(i))
    @property
    def header(self):
        return self._header

    @header.setter
    def header(self, value):
        if isinstance(value, SecGravityServiceHeader):
            self._header = value
        else:
            self._header = SecGravityServiceHeader.from_alipay_dict(value)
    @property
    def params(self):
        return self._params

    @params.setter
    def params(self, value):
        if isinstance(value, list):
            self._params = list()
            for i in value:
                if isinstance(i, GravityParam):
                    self._params.append(i)
                else:
                    self._params.append(GravityParam.from_alipay_dict(i))
    @property
    def product_id(self):
        return self._product_id

    @product_id.setter
    def product_id(self, value):
        self._product_id = value
    @property
    def session_token(self):
        return self._session_token

    @session_token.setter
    def session_token(self, value):
        self._session_token = value


    def to_alipay_dict(self):
        params = dict()
        if self.authorized_client_id:
            if hasattr(self.authorized_client_id, 'to_alipay_dict'):
                params['authorized_client_id'] = self.authorized_client_id.to_alipay_dict()
            else:
                params['authorized_client_id'] = self.authorized_client_id
        if self.extension:
            if isinstance(self.extension, list):
                for i in range(0, len(self.extension)):
                    element = self.extension[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.extension[i] = element.to_alipay_dict()
            if hasattr(self.extension, 'to_alipay_dict'):
                params['extension'] = self.extension.to_alipay_dict()
            else:
                params['extension'] = self.extension
        if self.header:
            if hasattr(self.header, 'to_alipay_dict'):
                params['header'] = self.header.to_alipay_dict()
            else:
                params['header'] = self.header
        if self.params:
            if isinstance(self.params, list):
                for i in range(0, len(self.params)):
                    element = self.params[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.params[i] = element.to_alipay_dict()
            if hasattr(self.params, 'to_alipay_dict'):
                params['params'] = self.params.to_alipay_dict()
            else:
                params['params'] = self.params
        if self.product_id:
            if hasattr(self.product_id, 'to_alipay_dict'):
                params['product_id'] = self.product_id.to_alipay_dict()
            else:
                params['product_id'] = self.product_id
        if self.session_token:
            if hasattr(self.session_token, 'to_alipay_dict'):
                params['session_token'] = self.session_token.to_alipay_dict()
            else:
                params['session_token'] = self.session_token
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityRiskGravityConsultModel()
        if 'authorized_client_id' in d:
            o.authorized_client_id = d['authorized_client_id']
        if 'extension' in d:
            o.extension = d['extension']
        if 'header' in d:
            o.header = d['header']
        if 'params' in d:
            o.params = d['params']
        if 'product_id' in d:
            o.product_id = d['product_id']
        if 'session_token' in d:
            o.session_token = d['session_token']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SubAccountAndBindDTO import SubAccountAndBindDTO


class SubAccountInfoDTO(object):

    def __init__(self):
        self._apply_status = None
        self._sub_account_info = None

    @property
    def apply_status(self):
        return self._apply_status

    @apply_status.setter
    def apply_status(self, value):
        self._apply_status = value
    @property
    def sub_account_info(self):
        return self._sub_account_info

    @sub_account_info.setter
    def sub_account_info(self, value):
        if isinstance(value, SubAccountAndBindDTO):
            self._sub_account_info = value
        else:
            self._sub_account_info = SubAccountAndBindDTO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.apply_status:
            if hasattr(self.apply_status, 'to_alipay_dict'):
                params['apply_status'] = self.apply_status.to_alipay_dict()
            else:
                params['apply_status'] = self.apply_status
        if self.sub_account_info:
            if hasattr(self.sub_account_info, 'to_alipay_dict'):
                params['sub_account_info'] = self.sub_account_info.to_alipay_dict()
            else:
                params['sub_account_info'] = self.sub_account_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SubAccountInfoDTO()
        if 'apply_status' in d:
            o.apply_status = d['apply_status']
        if 'sub_account_info' in d:
            o.sub_account_info = d['sub_account_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ExtCardInfo import ExtCardInfo


class AlipayFundAccountbookCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundAccountbookCreateResponse, self).__init__()
        self._account_book_id = None
        self._ext_card_info = None

    @property
    def account_book_id(self):
        return self._account_book_id

    @account_book_id.setter
    def account_book_id(self, value):
        self._account_book_id = value
    @property
    def ext_card_info(self):
        return self._ext_card_info

    @ext_card_info.setter
    def ext_card_info(self, value):
        if isinstance(value, ExtCardInfo):
            self._ext_card_info = value
        else:
            self._ext_card_info = ExtCardInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayFundAccountbookCreateResponse, self).parse_response_content(response_content)
        if 'account_book_id' in response:
            self.account_book_id = response['account_book_id']
        if 'ext_card_info' in response:
            self.ext_card_info = response['ext_card_info']
